# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_remoteclient_service_messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1steammessages_remoteclient_service_messages.proto\"%\n#CRemoteClient_CreateSession_Request\"M\n$CRemoteClient_CreateSession_Response\x12\x12\n\nsession_id\x18\x01 \x01(\x06\x12\x11\n\teuniverse\x18\x02 \x01(\x05\">\n(CRemoteClient_DeleteSession_Notification\x12\x12\n\nsession_id\x18\x01 \x01(\x06\"8\n\"CRemoteClient_StartPairing_Request\x12\x12\n\nsession_id\x18\x01 \x01(\x06\"2\n#CRemoteClient_StartPairing_Response\x12\x0b\n\x03pin\x18\x01 \x01(\r\"^\n$CRemoteClient_SetPairingInfo_Request\x12\x12\n\nsession_id\x18\x01 \x01(\x06\x12\x11\n\tdevice_id\x18\x02 \x01(\x06\x12\x0f\n\x07request\x18\x03 \x01(\x0c\"\'\n%CRemoteClient_SetPairingInfo_Response\"3\n$CRemoteClient_GetPairingInfo_Request\x12\x0b\n\x03pin\x18\x01 \x01(\r\"_\n%CRemoteClient_GetPairingInfo_Response\x12\x12\n\nsession_id\x18\x01 \x01(\x06\x12\x11\n\tdevice_id\x18\x02 \x01(\x06\x12\x0f\n\x07request\x18\x03 \x01(\x0c\"9\n#CRemoteClient_CancelPairing_Request\x12\x12\n\nsession_id\x18\x01 \x01(\x06\"&\n$CRemoteClient_CancelPairing_Response\"i\n/CRemoteClient_RegisterStatusUpdate_Notification\x12\x12\n\nsession_id\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x11\n\tdevice_id\x18\x03 \x01(\x06\"X\n1CRemoteClient_UnregisterStatusUpdate_Notification\x12\x12\n\nsession_id\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"h\n\x1b\x43RemoteClient_DeviceDetails\x12\x1c\n\x14\x64\x65vice_friendly_name\x18\x01 \x01(\t\x12\x0f\n\x07os_type\x18\x02 \x01(\x05\x12\x1a\n\x12gaming_device_type\x18\x03 \x01(\r\"\x84\x01\n!CRemoteClient_Online_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10remote_client_id\x18\x02 \x01(\x06\x12\x34\n\x0e\x64\x65vice_details\x18\x03 \x01(\x0b\x32\x1c.CRemoteClient_DeviceDetails\"(\n&CRemoteClient_GetRecentClients_Request\"}\n\x19\x43RemoteClient_ClientLogin\x12\x18\n\x10remote_client_id\x18\x01 \x01(\x06\x12\x10\n\x08token_id\x18\x02 \x01(\x06\x12\x34\n\x0e\x64\x65vice_details\x18\x03 \x01(\x0b\x32\x1c.CRemoteClient_DeviceDetails\"\xc1\x01\n\x1b\x43RemoteClient_ClientDetails\x12\x18\n\x10remote_client_id\x18\x01 \x01(\x06\x12\x34\n\x0e\x64\x65vice_details\x18\x02 \x01(\x0b\x32\x1c.CRemoteClient_DeviceDetails\x12\x11\n\tlast_seen\x18\x04 \x01(\x04\x12\x0c\n\x04\x63ity\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x07 \x01(\t\x12\x11\n\tis_online\x18\x08 \x01(\x08\"X\n\'CRemoteClient_GetRecentClients_Response\x12-\n\x07\x63lients\x18\x01 \x03(\x0b\x32\x1c.CRemoteClient_ClientDetails\"\x83\x01\n\x12\x43RemoteClient_Task\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x14.ECLientTaskListType:\x1ak_EClientTask_DownloadClip\x12\x0f\n\x07task_id\x18\x02 \x01(\x06\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0f\n\x07\x66ile_id\x18\x04 \x01(\x03\"b\n#CRemoteClient_AddClientTask_Request\x12\x18\n\x10remote_client_id\x18\x01 \x01(\x06\x12!\n\x04task\x18\x02 \x01(\x0b\x32\x13.CRemoteClient_Task\"&\n$CRemoteClient_AddClientTask_Response\"f\n#CRemoteClient_TaskList_Notification\x12\x18\n\x10remote_client_id\x18\x01 \x01(\x06\x12%\n\x08tasklist\x18\x02 \x03(\x0b\x32\x13.CRemoteClient_Task\"g\n&CRemoteClient_MarkTaskComplete_Request\x12\x18\n\x10remote_client_id\x18\x01 \x01(\x06\x12\x0f\n\x07task_id\x18\x02 \x01(\x06\x12\x12\n\ncontent_id\x18\x03 \x01(\t\")\n\'CRemoteClient_MarkTaskComplete_Response\"_\n\'CRemoteClient_RemotePacket_Notification\x12\x12\n\nsession_id\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\"M\n&CRemoteClient_ReplyPacket_Notification\x12\x12\n\nsession_id\x18\x01 \x01(\x06\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"6\n CRemoteClient_GetReplies_Request\x12\x12\n\nsession_id\x18\x01 \x01(\x06\"4\n!CRemoteClient_GetReplies_Response\x12\x0f\n\x07payload\x18\x01 \x03(\x0c\"P\n)CRemoteClient_AllocateRelayServer_Request\x12\x0e\n\x06\x63\x65llid\x18\x01 \x01(\r\x12\x13\n\x0b\x63redentials\x18\x02 \x01(\t\"B\n*CRemoteClient_AllocateRelayServer_Response\x12\x14\n\x0crelay_server\x18\x01 \x01(\t\"2\n!CRemoteClient_AllocateSDR_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"$\n\"CRemoteClient_AllocateSDR_Response\"_\n)CRemoteClient_SteamBroadcast_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08\x63lientid\x18\x02 \x01(\x06\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"\x93\x01\n\'CRemoteClient_SteamToSteam_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0csrc_clientid\x18\x02 \x01(\x06\x12\x14\n\x0c\x64st_clientid\x18\x03 \x01(\x06\x12\x10\n\x08secretid\x18\x04 \x01(\r\x12\x19\n\x11\x65ncrypted_payload\x18\x05 \x01(\x0c\"\xb8\x01\n\"CRemotePlay_SessionStarted_Request\x12\x17\n\x0fhost_account_id\x18\x01 \x01(\r\x12\x19\n\x11\x63lient_account_id\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12\x1a\n\x12\x64\x65vice_form_factor\x18\x04 \x01(\x05\x12\x1c\n\x14remote_play_together\x18\x05 \x01(\x08\x12\x15\n\rguest_session\x18\x06 \x01(\x08\"8\n#CRemotePlay_SessionStarted_Response\x12\x11\n\trecord_id\x18\x01 \x01(\x06\"u\n\'CRemotePlay_SessionStopped_Notification\x12\x11\n\trecord_id\x18\x01 \x01(\x06\x12\x11\n\tused_x264\x18\x02 \x01(\x08\x12\x11\n\tused_h264\x18\x03 \x01(\x08\x12\x11\n\tused_hevc\x18\x04 \x01(\x08\"\xb7\x06\n CRemotePlayTogether_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12G\n\rgroup_updated\x18\x02 \x01(\x0b\x32..CRemotePlayTogether_Notification.GroupUpdatedH\x00\x1a\x8c\x01\n\x06Player\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0f\n\x07guestid\x18\x02 \x01(\r\x12\x13\n\x0b\x61vatar_hash\x18\x03 \x01(\x0c\x12\x18\n\x10keyboard_enabled\x18\x04 \x01(\x08\x12\x15\n\rmouse_enabled\x18\x05 \x01(\x08\x12\x1a\n\x12\x63ontroller_enabled\x18\x06 \x01(\x08\x1a:\n\x17\x43ontrollerSlot_obsolete\x12\x0e\n\x06slotid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x1as\n\x0e\x43ontrollerSlot\x12\x0e\n\x06slotid\x18\x01 \x01(\r\x12\x38\n\x06player\x18\x02 \x01(\x0b\x32(.CRemotePlayTogether_Notification.Player\x12\x17\n\x0f\x63ontroller_type\x18\x03 \x01(\x05\x1a\xed\x02\n\x0cGroupUpdated\x12\x14\n\x0chost_steamid\x18\x01 \x01(\x06\x12\x15\n\rhost_clientid\x18\x02 \x01(\x06\x12\x18\n\x10players_obsolete\x18\x03 \x03(\x06\x12\x13\n\x0bhost_gameid\x18\x04 \x01(\x06\x12\\\n\x19\x63ontroller_slots_obsolete\x18\x05 \x03(\x0b\x32\x39.CRemotePlayTogether_Notification.ControllerSlot_obsolete\x12\x17\n\x0fhas_new_players\x18\x06 \x01(\x08\x12>\n\x0cplayer_slots\x18\x07 \x03(\x0b\x32(.CRemotePlayTogether_Notification.Player\x12J\n\x10\x63ontroller_slots\x18\x08 \x03(\x0b\x32\x30.CRemotePlayTogether_Notification.ControllerSlotB\t\n\x07Message\"d\n8CRemoteClient_CreateRemotePlayTogetherInvitation_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11launch_parameters\x18\x02 \x01(\t\"T\n9CRemoteClient_CreateRemotePlayTogetherInvitation_Response\x12\x17\n\x0finvitation_code\x18\x01 \x01(\t\"S\n8CRemoteClient_DeleteRemotePlayTogetherInvitation_Request\x12\x17\n\x0finvitation_code\x18\x01 \x01(\t\";\n9CRemoteClient_DeleteRemotePlayTogetherInvitation_Response\"S\n8CRemoteClient_LookupRemotePlayTogetherInvitation_Request\x12\x17\n\x0finvitation_code\x18\x01 \x01(\t\"S\n9CRemoteClient_LookupRemotePlayTogetherInvitation_Response\x12\x16\n\x0einvitation_url\x18\x01 \x01(\t\"\xba\x04\n\x1d\x43\x43MRemoteClient_ClientMessage\x12\x46\n\x16\x63reate_session_request\x18\x01 \x01(\x0b\x32$.CRemoteClient_CreateSession_RequestH\x00\x12\x44\n\x15start_pairing_request\x18\x02 \x01(\x0b\x32#.CRemoteClient_StartPairing_RequestH\x00\x12I\n\x18set_pairing_info_request\x18\x03 \x01(\x0b\x32%.CRemoteClient_SetPairingInfo_RequestH\x00\x12\x46\n\x16\x63\x61ncel_pairing_request\x18\x04 \x01(\x0b\x32$.CRemoteClient_CancelPairing_RequestH\x00\x12R\n\x16register_status_update\x18\x05 \x01(\x0b\x32\x30.CRemoteClient_RegisterStatusUpdate_NotificationH\x00\x12V\n\x18unregister_status_update\x18\x06 \x01(\x0b\x32\x32.CRemoteClient_UnregisterStatusUpdate_NotificationH\x00\x12\x41\n\rremote_packet\x18\x07 \x01(\x0b\x32(.CRemoteClient_RemotePacket_NotificationH\x00\x42\t\n\x07Message\"\x9f\x03\n\x1d\x43\x43MRemoteClient_ServerMessage\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12H\n\x17\x63reate_session_response\x18\x02 \x01(\x0b\x32%.CRemoteClient_CreateSession_ResponseH\x00\x12\x46\n\x16start_pairing_response\x18\x03 \x01(\x0b\x32$.CRemoteClient_StartPairing_ResponseH\x00\x12K\n\x19set_pairing_info_response\x18\x04 \x01(\x0b\x32&.CRemoteClient_SetPairingInfo_ResponseH\x00\x12H\n\x17\x63\x61ncel_pairing_response\x18\x05 \x01(\x0b\x32%.CRemoteClient_CancelPairing_ResponseH\x00\x12:\n\x0creply_packet\x18\x06 \x01(\x0b\x32\".CRemoteClient_GetReplies_ResponseH\x00\x42\t\n\x07Message*5\n\x13\x45\x43LientTaskListType\x12\x1e\n\x1ak_EClientTask_DownloadClip\x10\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_remoteclient_service_messages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ECLIENTTASKLISTTYPE._serialized_start=5608
  _ECLIENTTASKLISTTYPE._serialized_end=5661
  _CREMOTECLIENT_CREATESESSION_REQUEST._serialized_start=53
  _CREMOTECLIENT_CREATESESSION_REQUEST._serialized_end=90
  _CREMOTECLIENT_CREATESESSION_RESPONSE._serialized_start=92
  _CREMOTECLIENT_CREATESESSION_RESPONSE._serialized_end=169
  _CREMOTECLIENT_DELETESESSION_NOTIFICATION._serialized_start=171
  _CREMOTECLIENT_DELETESESSION_NOTIFICATION._serialized_end=233
  _CREMOTECLIENT_STARTPAIRING_REQUEST._serialized_start=235
  _CREMOTECLIENT_STARTPAIRING_REQUEST._serialized_end=291
  _CREMOTECLIENT_STARTPAIRING_RESPONSE._serialized_start=293
  _CREMOTECLIENT_STARTPAIRING_RESPONSE._serialized_end=343
  _CREMOTECLIENT_SETPAIRINGINFO_REQUEST._serialized_start=345
  _CREMOTECLIENT_SETPAIRINGINFO_REQUEST._serialized_end=439
  _CREMOTECLIENT_SETPAIRINGINFO_RESPONSE._serialized_start=441
  _CREMOTECLIENT_SETPAIRINGINFO_RESPONSE._serialized_end=480
  _CREMOTECLIENT_GETPAIRINGINFO_REQUEST._serialized_start=482
  _CREMOTECLIENT_GETPAIRINGINFO_REQUEST._serialized_end=533
  _CREMOTECLIENT_GETPAIRINGINFO_RESPONSE._serialized_start=535
  _CREMOTECLIENT_GETPAIRINGINFO_RESPONSE._serialized_end=630
  _CREMOTECLIENT_CANCELPAIRING_REQUEST._serialized_start=632
  _CREMOTECLIENT_CANCELPAIRING_REQUEST._serialized_end=689
  _CREMOTECLIENT_CANCELPAIRING_RESPONSE._serialized_start=691
  _CREMOTECLIENT_CANCELPAIRING_RESPONSE._serialized_end=729
  _CREMOTECLIENT_REGISTERSTATUSUPDATE_NOTIFICATION._serialized_start=731
  _CREMOTECLIENT_REGISTERSTATUSUPDATE_NOTIFICATION._serialized_end=836
  _CREMOTECLIENT_UNREGISTERSTATUSUPDATE_NOTIFICATION._serialized_start=838
  _CREMOTECLIENT_UNREGISTERSTATUSUPDATE_NOTIFICATION._serialized_end=926
  _CREMOTECLIENT_DEVICEDETAILS._serialized_start=928
  _CREMOTECLIENT_DEVICEDETAILS._serialized_end=1032
  _CREMOTECLIENT_ONLINE_NOTIFICATION._serialized_start=1035
  _CREMOTECLIENT_ONLINE_NOTIFICATION._serialized_end=1167
  _CREMOTECLIENT_GETRECENTCLIENTS_REQUEST._serialized_start=1169
  _CREMOTECLIENT_GETRECENTCLIENTS_REQUEST._serialized_end=1209
  _CREMOTECLIENT_CLIENTLOGIN._serialized_start=1211
  _CREMOTECLIENT_CLIENTLOGIN._serialized_end=1336
  _CREMOTECLIENT_CLIENTDETAILS._serialized_start=1339
  _CREMOTECLIENT_CLIENTDETAILS._serialized_end=1532
  _CREMOTECLIENT_GETRECENTCLIENTS_RESPONSE._serialized_start=1534
  _CREMOTECLIENT_GETRECENTCLIENTS_RESPONSE._serialized_end=1622
  _CREMOTECLIENT_TASK._serialized_start=1625
  _CREMOTECLIENT_TASK._serialized_end=1756
  _CREMOTECLIENT_ADDCLIENTTASK_REQUEST._serialized_start=1758
  _CREMOTECLIENT_ADDCLIENTTASK_REQUEST._serialized_end=1856
  _CREMOTECLIENT_ADDCLIENTTASK_RESPONSE._serialized_start=1858
  _CREMOTECLIENT_ADDCLIENTTASK_RESPONSE._serialized_end=1896
  _CREMOTECLIENT_TASKLIST_NOTIFICATION._serialized_start=1898
  _CREMOTECLIENT_TASKLIST_NOTIFICATION._serialized_end=2000
  _CREMOTECLIENT_MARKTASKCOMPLETE_REQUEST._serialized_start=2002
  _CREMOTECLIENT_MARKTASKCOMPLETE_REQUEST._serialized_end=2105
  _CREMOTECLIENT_MARKTASKCOMPLETE_RESPONSE._serialized_start=2107
  _CREMOTECLIENT_MARKTASKCOMPLETE_RESPONSE._serialized_end=2148
  _CREMOTECLIENT_REMOTEPACKET_NOTIFICATION._serialized_start=2150
  _CREMOTECLIENT_REMOTEPACKET_NOTIFICATION._serialized_end=2245
  _CREMOTECLIENT_REPLYPACKET_NOTIFICATION._serialized_start=2247
  _CREMOTECLIENT_REPLYPACKET_NOTIFICATION._serialized_end=2324
  _CREMOTECLIENT_GETREPLIES_REQUEST._serialized_start=2326
  _CREMOTECLIENT_GETREPLIES_REQUEST._serialized_end=2380
  _CREMOTECLIENT_GETREPLIES_RESPONSE._serialized_start=2382
  _CREMOTECLIENT_GETREPLIES_RESPONSE._serialized_end=2434
  _CREMOTECLIENT_ALLOCATERELAYSERVER_REQUEST._serialized_start=2436
  _CREMOTECLIENT_ALLOCATERELAYSERVER_REQUEST._serialized_end=2516
  _CREMOTECLIENT_ALLOCATERELAYSERVER_RESPONSE._serialized_start=2518
  _CREMOTECLIENT_ALLOCATERELAYSERVER_RESPONSE._serialized_end=2584
  _CREMOTECLIENT_ALLOCATESDR_REQUEST._serialized_start=2586
  _CREMOTECLIENT_ALLOCATESDR_REQUEST._serialized_end=2636
  _CREMOTECLIENT_ALLOCATESDR_RESPONSE._serialized_start=2638
  _CREMOTECLIENT_ALLOCATESDR_RESPONSE._serialized_end=2674
  _CREMOTECLIENT_STEAMBROADCAST_NOTIFICATION._serialized_start=2676
  _CREMOTECLIENT_STEAMBROADCAST_NOTIFICATION._serialized_end=2771
  _CREMOTECLIENT_STEAMTOSTEAM_NOTIFICATION._serialized_start=2774
  _CREMOTECLIENT_STEAMTOSTEAM_NOTIFICATION._serialized_end=2921
  _CREMOTEPLAY_SESSIONSTARTED_REQUEST._serialized_start=2924
  _CREMOTEPLAY_SESSIONSTARTED_REQUEST._serialized_end=3108
  _CREMOTEPLAY_SESSIONSTARTED_RESPONSE._serialized_start=3110
  _CREMOTEPLAY_SESSIONSTARTED_RESPONSE._serialized_end=3166
  _CREMOTEPLAY_SESSIONSTOPPED_NOTIFICATION._serialized_start=3168
  _CREMOTEPLAY_SESSIONSTOPPED_NOTIFICATION._serialized_end=3285
  _CREMOTEPLAYTOGETHER_NOTIFICATION._serialized_start=3288
  _CREMOTEPLAYTOGETHER_NOTIFICATION._serialized_end=4111
  _CREMOTEPLAYTOGETHER_NOTIFICATION_PLAYER._serialized_start=3415
  _CREMOTEPLAYTOGETHER_NOTIFICATION_PLAYER._serialized_end=3555
  _CREMOTEPLAYTOGETHER_NOTIFICATION_CONTROLLERSLOT_OBSOLETE._serialized_start=3557
  _CREMOTEPLAYTOGETHER_NOTIFICATION_CONTROLLERSLOT_OBSOLETE._serialized_end=3615
  _CREMOTEPLAYTOGETHER_NOTIFICATION_CONTROLLERSLOT._serialized_start=3617
  _CREMOTEPLAYTOGETHER_NOTIFICATION_CONTROLLERSLOT._serialized_end=3732
  _CREMOTEPLAYTOGETHER_NOTIFICATION_GROUPUPDATED._serialized_start=3735
  _CREMOTEPLAYTOGETHER_NOTIFICATION_GROUPUPDATED._serialized_end=4100
  _CREMOTECLIENT_CREATEREMOTEPLAYTOGETHERINVITATION_REQUEST._serialized_start=4113
  _CREMOTECLIENT_CREATEREMOTEPLAYTOGETHERINVITATION_REQUEST._serialized_end=4213
  _CREMOTECLIENT_CREATEREMOTEPLAYTOGETHERINVITATION_RESPONSE._serialized_start=4215
  _CREMOTECLIENT_CREATEREMOTEPLAYTOGETHERINVITATION_RESPONSE._serialized_end=4299
  _CREMOTECLIENT_DELETEREMOTEPLAYTOGETHERINVITATION_REQUEST._serialized_start=4301
  _CREMOTECLIENT_DELETEREMOTEPLAYTOGETHERINVITATION_REQUEST._serialized_end=4384
  _CREMOTECLIENT_DELETEREMOTEPLAYTOGETHERINVITATION_RESPONSE._serialized_start=4386
  _CREMOTECLIENT_DELETEREMOTEPLAYTOGETHERINVITATION_RESPONSE._serialized_end=4445
  _CREMOTECLIENT_LOOKUPREMOTEPLAYTOGETHERINVITATION_REQUEST._serialized_start=4447
  _CREMOTECLIENT_LOOKUPREMOTEPLAYTOGETHERINVITATION_REQUEST._serialized_end=4530
  _CREMOTECLIENT_LOOKUPREMOTEPLAYTOGETHERINVITATION_RESPONSE._serialized_start=4532
  _CREMOTECLIENT_LOOKUPREMOTEPLAYTOGETHERINVITATION_RESPONSE._serialized_end=4615
  _CCMREMOTECLIENT_CLIENTMESSAGE._serialized_start=4618
  _CCMREMOTECLIENT_CLIENTMESSAGE._serialized_end=5188
  _CCMREMOTECLIENT_SERVERMESSAGE._serialized_start=5191
  _CCMREMOTECLIENT_SERVERMESSAGE._serialized_end=5606
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_bluetooth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dwebuimessages_bluetooth.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"$\n\"CBluetoothManager_GetState_Request\"-\n\x1f\x43MsgBluetoothManagerAdapterInfo\x12\n\n\x02id\x18\x01 \x01(\r\"\xca\x01\n\x1e\x43MsgBluetoothManagerDeviceInfo\x12\n\n\x02id\x18\x01 \x01(\r\x12\x18\n\x10should_hide_hint\x18\x02 \x01(\x08\x12\x43\n\x05\x65type\x18\x03 \x01(\x0e\x32\x15.EBluetoothDeviceType:\x1dk_BluetoothDeviceType_Invalid\x12\x14\n\x0cis_connected\x18\x04 \x01(\x08\x12\x11\n\tis_paired\x18\x05 \x01(\x08\x12\x14\n\x0cstrength_raw\x18\x06 \x01(\x05\"\xd5\x01\n#CBluetoothManager_GetState_Response\x12\x1c\n\x14is_service_available\x18\x01 \x01(\x08\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\x12\x16\n\x0eis_discovering\x18\x03 \x01(\x08\x12\x32\n\x08\x61\x64\x61pters\x18\x04 \x03(\x0b\x32 .CMsgBluetoothManagerAdapterInfo\x12\x30\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32\x1f.CMsgBluetoothManagerDeviceInfo\"9\n+CBluetoothManager_GetAdapterDetails_Request\x12\n\n\x02id\x18\x01 \x01(\r\"z\n\"CMsgBluetoothManagerAdapterDetails\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x0b\n\x03mac\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\x12\x16\n\x0eis_discovering\x18\x05 \x01(\x08\"d\n,CBluetoothManager_GetAdapterDetails_Response\x12\x34\n\x07\x61\x64\x61pter\x18\x01 \x01(\x0b\x32#.CMsgBluetoothManagerAdapterDetails\"8\n*CBluetoothManager_GetDeviceDetails_Request\x12\n\n\x02id\x18\x01 \x01(\r\"\xe8\x02\n!CMsgBluetoothManagerDeviceDetails\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x15\n\nadapter_id\x18\x02 \x01(\r:\x01\x30\x12\x43\n\x05\x65type\x18\x03 \x01(\x0e\x32\x15.EBluetoothDeviceType:\x1dk_BluetoothDeviceType_Invalid\x12\x0b\n\x03mac\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x14\n\x0cis_connected\x18\x06 \x01(\x08\x12\x11\n\tis_paired\x18\x07 \x01(\x08\x12\x12\n\nis_pairing\x18\x08 \x01(\x08\x12\x14\n\x0cwake_allowed\x18\t \x01(\x08\x12\x1e\n\x16wake_allowed_supported\x18\n \x01(\x08\x12\x17\n\x0f\x62\x61ttery_percent\x18\x0b \x01(\x05\x12\x1d\n\x15operation_in_progress\x18\x0c \x01(\x08\x12\x12\n\nis_trusted\x18\r \x01(\x08\"a\n+CBluetoothManager_GetDeviceDetails_Response\x12\x32\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\".CMsgBluetoothManagerDeviceDetails\"-\n+CBluetoothManager_StateChanged_Notification\";\n(CBluetoothManager_SetDiscovering_Request\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"+\n)CBluetoothManager_SetDiscovering_Response\"0\n\x1e\x43\x42luetoothManager_Pair_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"!\n\x1f\x43\x42luetoothManager_Pair_Response\"6\n$CBluetoothManager_CancelPair_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"\'\n%CBluetoothManager_CancelPair_Response\"2\n CBluetoothManager_Forget_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"#\n!CBluetoothManager_Forget_Response\"3\n!CBluetoothManager_Connect_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"$\n\"CBluetoothManager_Connect_Response\"6\n$CBluetoothManager_Disconnect_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\"\'\n%CBluetoothManager_Disconnect_Response\"K\n(CBluetoothManager_SetWakeAllowed_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\x0f\n\x07\x61llowed\x18\x02 \x01(\x08\"+\n)CBluetoothManager_SetWakeAllowed_Response\"G\n$CBluetoothManager_SetTrusted_Request\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\x0f\n\x07trusted\x18\x02 \x01(\x08\"\'\n%CBluetoothManager_SetTrusted_Response2\xff\x08\n\x10\x42luetoothManager\x12U\n\x08GetState\x12#.CBluetoothManager_GetState_Request\x1a$.CBluetoothManager_GetState_Response\x12p\n\x11GetAdapterDetails\x12,.CBluetoothManager_GetAdapterDetails_Request\x1a-.CBluetoothManager_GetAdapterDetails_Response\x12m\n\x10GetDeviceDetails\x12+.CBluetoothManager_GetDeviceDetails_Request\x1a,.CBluetoothManager_GetDeviceDetails_Response\x12T\n\x12NotifyStateChanged\x12,.CBluetoothManager_StateChanged_Notification\x1a\x10.WebUINoResponse\x12g\n\x0eSetDiscovering\x12).CBluetoothManager_SetDiscovering_Request\x1a*.CBluetoothManager_SetDiscovering_Response\x12I\n\x04Pair\x12\x1f.CBluetoothManager_Pair_Request\x1a .CBluetoothManager_Pair_Response\x12[\n\nCancelPair\x12%.CBluetoothManager_CancelPair_Request\x1a&.CBluetoothManager_CancelPair_Response\x12O\n\x06\x46orget\x12!.CBluetoothManager_Forget_Request\x1a\".CBluetoothManager_Forget_Response\x12R\n\x07\x43onnect\x12\".CBluetoothManager_Connect_Request\x1a#.CBluetoothManager_Connect_Response\x12[\n\nDisconnect\x12%.CBluetoothManager_Disconnect_Request\x1a&.CBluetoothManager_Disconnect_Response\x12g\n\x0eSetWakeAllowed\x12).CBluetoothManager_SetWakeAllowed_Request\x1a*.CBluetoothManager_SetWakeAllowed_Response\x12[\n\nSetTrusted\x12%.CBluetoothManager_SetTrusted_Request\x1a&.CBluetoothManager_SetTrusted_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_bluetooth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _BLUETOOTHMANAGER._options = None
  _BLUETOOTHMANAGER._serialized_options = b'\200\227\"\001'
  _CBLUETOOTHMANAGER_GETSTATE_REQUEST._serialized_start=98
  _CBLUETOOTHMANAGER_GETSTATE_REQUEST._serialized_end=134
  _CMSGBLUETOOTHMANAGERADAPTERINFO._serialized_start=136
  _CMSGBLUETOOTHMANAGERADAPTERINFO._serialized_end=181
  _CMSGBLUETOOTHMANAGERDEVICEINFO._serialized_start=184
  _CMSGBLUETOOTHMANAGERDEVICEINFO._serialized_end=386
  _CBLUETOOTHMANAGER_GETSTATE_RESPONSE._serialized_start=389
  _CBLUETOOTHMANAGER_GETSTATE_RESPONSE._serialized_end=602
  _CBLUETOOTHMANAGER_GETADAPTERDETAILS_REQUEST._serialized_start=604
  _CBLUETOOTHMANAGER_GETADAPTERDETAILS_REQUEST._serialized_end=661
  _CMSGBLUETOOTHMANAGERADAPTERDETAILS._serialized_start=663
  _CMSGBLUETOOTHMANAGERADAPTERDETAILS._serialized_end=785
  _CBLUETOOTHMANAGER_GETADAPTERDETAILS_RESPONSE._serialized_start=787
  _CBLUETOOTHMANAGER_GETADAPTERDETAILS_RESPONSE._serialized_end=887
  _CBLUETOOTHMANAGER_GETDEVICEDETAILS_REQUEST._serialized_start=889
  _CBLUETOOTHMANAGER_GETDEVICEDETAILS_REQUEST._serialized_end=945
  _CMSGBLUETOOTHMANAGERDEVICEDETAILS._serialized_start=948
  _CMSGBLUETOOTHMANAGERDEVICEDETAILS._serialized_end=1308
  _CBLUETOOTHMANAGER_GETDEVICEDETAILS_RESPONSE._serialized_start=1310
  _CBLUETOOTHMANAGER_GETDEVICEDETAILS_RESPONSE._serialized_end=1407
  _CBLUETOOTHMANAGER_STATECHANGED_NOTIFICATION._serialized_start=1409
  _CBLUETOOTHMANAGER_STATECHANGED_NOTIFICATION._serialized_end=1454
  _CBLUETOOTHMANAGER_SETDISCOVERING_REQUEST._serialized_start=1456
  _CBLUETOOTHMANAGER_SETDISCOVERING_REQUEST._serialized_end=1515
  _CBLUETOOTHMANAGER_SETDISCOVERING_RESPONSE._serialized_start=1517
  _CBLUETOOTHMANAGER_SETDISCOVERING_RESPONSE._serialized_end=1560
  _CBLUETOOTHMANAGER_PAIR_REQUEST._serialized_start=1562
  _CBLUETOOTHMANAGER_PAIR_REQUEST._serialized_end=1610
  _CBLUETOOTHMANAGER_PAIR_RESPONSE._serialized_start=1612
  _CBLUETOOTHMANAGER_PAIR_RESPONSE._serialized_end=1645
  _CBLUETOOTHMANAGER_CANCELPAIR_REQUEST._serialized_start=1647
  _CBLUETOOTHMANAGER_CANCELPAIR_REQUEST._serialized_end=1701
  _CBLUETOOTHMANAGER_CANCELPAIR_RESPONSE._serialized_start=1703
  _CBLUETOOTHMANAGER_CANCELPAIR_RESPONSE._serialized_end=1742
  _CBLUETOOTHMANAGER_FORGET_REQUEST._serialized_start=1744
  _CBLUETOOTHMANAGER_FORGET_REQUEST._serialized_end=1794
  _CBLUETOOTHMANAGER_FORGET_RESPONSE._serialized_start=1796
  _CBLUETOOTHMANAGER_FORGET_RESPONSE._serialized_end=1831
  _CBLUETOOTHMANAGER_CONNECT_REQUEST._serialized_start=1833
  _CBLUETOOTHMANAGER_CONNECT_REQUEST._serialized_end=1884
  _CBLUETOOTHMANAGER_CONNECT_RESPONSE._serialized_start=1886
  _CBLUETOOTHMANAGER_CONNECT_RESPONSE._serialized_end=1922
  _CBLUETOOTHMANAGER_DISCONNECT_REQUEST._serialized_start=1924
  _CBLUETOOTHMANAGER_DISCONNECT_REQUEST._serialized_end=1978
  _CBLUETOOTHMANAGER_DISCONNECT_RESPONSE._serialized_start=1980
  _CBLUETOOTHMANAGER_DISCONNECT_RESPONSE._serialized_end=2019
  _CBLUETOOTHMANAGER_SETWAKEALLOWED_REQUEST._serialized_start=2021
  _CBLUETOOTHMANAGER_SETWAKEALLOWED_REQUEST._serialized_end=2096
  _CBLUETOOTHMANAGER_SETWAKEALLOWED_RESPONSE._serialized_start=2098
  _CBLUETOOTHMANAGER_SETWAKEALLOWED_RESPONSE._serialized_end=2141
  _CBLUETOOTHMANAGER_SETTRUSTED_REQUEST._serialized_start=2143
  _CBLUETOOTHMANAGER_SETTRUSTED_REQUEST._serialized_end=2214
  _CBLUETOOTHMANAGER_SETTRUSTED_RESPONSE._serialized_start=2216
  _CBLUETOOTHMANAGER_SETTRUSTED_RESPONSE._serialized_end=2255
  _BLUETOOTHMANAGER._serialized_start=2258
  _BLUETOOTHMANAGER._serialized_end=3409
_builder.BuildServices(DESCRIPTOR, 'webuimessages_bluetooth_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_community.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsteammessages_community.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x0b\x65nums.proto\">\n\x1a\x43\x43ommunity_GetApps_Request\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\x05\x12\x10\n\x08language\x18\x02 \x01(\r\"B\n\x1b\x43\x43ommunity_GetApps_Response\x12#\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x15.CCDDBAppDetailCommon\"T\n1CCommunity_GetAppRichPresenceLocalization_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x10\n\x08language\x18\x02 \x01(\t\"\xa7\x02\n2CCommunity_GetAppRichPresenceLocalization_Response\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12R\n\x0btoken_lists\x18\x02 \x03(\x0b\x32=.CCommunity_GetAppRichPresenceLocalization_Response.TokenList\x1a$\n\x05Token\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1ah\n\tTokenList\x12\x10\n\x08language\x18\x01 \x01(\t\x12I\n\x06tokens\x18\x02 \x03(\x0b\x32\x39.CCommunity_GetAppRichPresenceLocalization_Response.Token\"\xcf\x02\n#CCommunity_GetCommentThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12M\n\x13\x63omment_thread_type\x18\x02 \x01(\x0e\x32\x13.ECommentThreadType:\x1bk_ECommentThreadTypeInvalid\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x05 \x01(\x06\x12\r\n\x05start\x18\x06 \x01(\x05\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x10\n\x08upvoters\x18\x08 \x01(\x05\x12\x17\n\x0finclude_deleted\x18\t \x01(\x08\x12\x12\n\ngidcomment\x18\n \x01(\x06\x12\x13\n\x0btime_oldest\x18\x0b \x01(\r\x12\x14\n\x0coldest_first\x18\x0c \x01(\x08\"\xf0\x02\n\x12\x43\x43ommunity_Comment\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x0f\n\x07upvotes\x18\x05 \x01(\x05\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x16\n\x0ehidden_by_user\x18\x07 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x08 \x01(\x08\x12!\n\tipaddress\x18\t \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x14\n\x0ctotal_hidden\x18\n \x01(\x05\x12\x17\n\x0fupvoted_by_user\x18\x0b \x01(\x08\x12/\n\treactions\x18\x0c \x03(\x0b\x32\x1c.CCommunity_Comment.Reaction\x12\x18\n\x10gidparentcomment\x18\r \x01(\x06\x1a-\n\x08Reaction\x12\x12\n\nreactionid\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\xce\x03\n$CCommunity_GetCommentThread_Response\x12%\n\x08\x63omments\x18\x01 \x03(\x0b\x32\x13.CCommunity_Comment\x12-\n\x10\x64\x65leted_comments\x18\x02 \x03(\x0b\x32\x13.CCommunity_Comment\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x04 \x01(\x06\x12\r\n\x05start\x18\x05 \x01(\x05\x12\r\n\x05\x63ount\x18\x06 \x01(\x05\x12\x13\n\x0btotal_count\x18\x07 \x01(\x05\x12\x0f\n\x07upvotes\x18\x08 \x01(\x05\x12\x10\n\x08upvoters\x18\t \x03(\r\x12\x17\n\x0fuser_subscribed\x18\n \x01(\x08\x12\x14\n\x0cuser_upvoted\x18\x0b \x01(\x08\x12\x18\n\x10\x61nswer_commentid\x18\x0c \x01(\x06\x12\x14\n\x0c\x61nswer_actor\x18\r \x01(\r\x12\x19\n\x11\x61nswer_actor_rank\x18\x0e \x01(\x05\x12\x10\n\x08\x63\x61n_post\x18\x0f \x01(\x08\x12\x1b\n\x13\x63omment_thread_type\x18\x10 \x01(\r\x12\x12\n\ngidfeature\x18\x11 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x12 \x01(\x06\"\xa2\x02\n&CCommunity_PostCommentToThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12M\n\x13\x63omment_thread_type\x18\x02 \x01(\x0e\x32\x13.ECommentThreadType:\x1bk_ECommentThreadTypeInvalid\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\x18\n\x10gidparentcomment\x18\x07 \x01(\x06\x12\x1e\n\x16suppress_notifications\x18\x08 \x01(\x08\x12\x11\n\tis_report\x18\t \x01(\x08\x12\x14\n\x0cstart_hidden\x18\n \x01(\x08\"v\n\'CCommunity_PostCommentToThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x06\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x0f\n\x07upvotes\x18\x04 \x01(\x05\"\xdb\x01\n*CCommunity_DeleteCommentFromThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12M\n\x13\x63omment_thread_type\x18\x02 \x01(\x0e\x32\x13.ECommentThreadType:\x1bk_ECommentThreadTypeInvalid\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x12\n\ngidcomment\x18\x05 \x01(\x06\x12\x10\n\x08undelete\x18\x06 \x01(\x08\"-\n+CCommunity_DeleteCommentFromThread_Response\"\xc0\x01\n$CCommunity_RateCommentThread_Request\x12\x19\n\x11\x63ommentthreadtype\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x12\n\ngidfeature\x18\x03 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x04\x12\x12\n\ngidcomment\x18\x05 \x01(\x04\x12\x0f\n\x07rate_up\x18\x06 \x01(\x08\x12\x1e\n\x16suppress_notifications\x18\x07 \x01(\x08\"\x89\x01\n%CCommunity_RateCommentThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x04\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x0f\n\x07upvotes\x18\x04 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x05 \x01(\x08\"\xaa\x01\n*CCommunity_GetCommentThreadRatings_Request\x12\x19\n\x11\x63ommentthreadtype\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x12\n\ngidfeature\x18\x03 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x04\x12\x12\n\ngidcomment\x18\x05 \x01(\x04\x12\x13\n\x0bmax_results\x18\x06 \x01(\r\"\x9c\x01\n+CCommunity_GetCommentThreadRatings_Response\x12\x17\n\x0f\x63ommentthreadid\x18\x01 \x01(\x04\x12\x12\n\ngidcomment\x18\x02 \x01(\x04\x12\x0f\n\x07upvotes\x18\x03 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x04 \x01(\x08\x12\x1a\n\x12upvoter_accountids\x18\x05 \x03(\r\"j\n\'CCommunity_RateClanAnnouncement_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lan_accountid\x18\x03 \x01(\r\"*\n(CCommunity_RateClanAnnouncement_Response\"K\n1CCommunity_GetClanAnnouncementVoteForUser_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\"Z\n2CCommunity_GetClanAnnouncementVoteForUser_Response\x12\x10\n\x08voted_up\x18\x01 \x01(\x08\x12\x12\n\nvoted_down\x18\x02 \x01(\x08\"\x9d\x01\n(CCommunity_GetClanLocGroupImages_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x37\n\x05group\x18\x02 \x01(\x0e\x32\x10.EClanImageGroup:\x16k_EClanImageGroup_None\x12\x10\n\x08language\x18\x03 \x01(\r\x12\x15\n\rloc_group_ids\x18\x04 \x03(\x04\"\x92\x02\n\x1c\x43\x43ommunity_ClanLocGroupImage\x12\x14\n\x0cloc_group_id\x18\x01 \x01(\x04\x12\x12\n\nimage_hash\x18\x02 \x01(\t\x12\x16\n\x0ethumbnail_hash\x18\x03 \x01(\t\x12\x44\n\tfile_type\x18\x04 \x01(\x0e\x32\x13.EClanImageFileType:\x1ck_EClanImageFileType_Unknown\x12\x37\n\x05group\x18\x05 \x01(\x0e\x32\x10.EClanImageGroup:\x16k_EClanImageGroup_None\x12\r\n\x05width\x18\x06 \x01(\r\x12\x0e\n\x06height\x18\x07 \x01(\r\x12\x12\n\nextensions\x18\x08 \x01(\t\"Z\n)CCommunity_GetClanLocGroupImages_Response\x12-\n\x06images\x18\x01 \x03(\x0b\x32\x1d.CCommunity_ClanLocGroupImage\"Y\n#CCommunity_GetAvatarHistory_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12!\n\x19\x66ilter_user_uploaded_only\x18\x02 \x01(\x08\"\xb6\x01\n$CCommunity_GetAvatarHistory_Response\x12\x41\n\x07\x61vatars\x18\x01 \x03(\x0b\x32\x30.CCommunity_GetAvatarHistory_Response.AvatarData\x1aK\n\nAvatarData\x12\x13\n\x0b\x61vatar_sha1\x18\x01 \x01(\t\x12\x15\n\ruser_uploaded\x18\x02 \x01(\x08\x12\x11\n\ttimestamp\x18\x03 \x01(\r\"Q\n.CCommunity_GetClanEventCrowdInMetadata_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\"f\n/CCommunity_GetClanEventCrowdInMetadata_Response\x12\x1a\n\x12\x63rowdin_project_id\x18\x01 \x01(\x04\x12\x17\n\x0f\x63rowdin_file_id\x18\x02 \x01(\x04\"<\n)CCommunity_GetClanCrowdInMetadata_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\x7f\n*CCommunity_GetClanCrowdInMetadata_Response\x12\x1a\n\x12\x63rowdin_project_id\x18\x01 \x01(\x04\x12\x1c\n\x14\x63rowdin_directory_id\x18\x02 \x01(\x04\x12\x17\n\x0fpush_by_default\x18\x03 \x01(\x08\"c\n.CCommunity_FetchTranslationFromCrowdIn_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\x12\x10\n\x08language\x18\x03 \x01(\x05\"1\n/CCommunity_FetchTranslationFromCrowdIn_Response\"\x83\x02\n\'CCommunity_HideAndReportComment_Request\x12\x12\n\ngidfeature\x18\x01 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x02 \x01(\x04\x12\x12\n\ngidcomment\x18\x03 \x01(\x04\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\x12\x19\n\x11\x63ommentthreadtype\x18\x05 \x01(\t\x12\x0c\n\x04hide\x18\x06 \x01(\x08\x12L\n\rreport_reason\x18\x07 \x01(\x0e\x32\x15.EContentReportReason:\x1ek_EContentReportReason_Invalid\x12\x13\n\x0breport_text\x18\x08 \x01(\t\"*\n(CCommunity_HideAndReportComment_Response\"/\n\x0c\x43\x41ppPriority\x12\x10\n\x08priority\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x03(\r\"\xba\x02\n*CCommunity_GetUserPartnerEventNews_Request\x12\r\n\x05\x63ount\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x1a\n\x12rtime32_start_time\x18\x03 \x01(\r\x12\x18\n\x10rtime32_end_time\x18\x04 \x01(\r\x12\x1b\n\x13language_preference\x18\x05 \x03(\r\x12/\n\x11\x66ilter_event_type\x18\x06 \x03(\x0e\x32\x14.EProtoClanEventType\x12\x17\n\x0f\x66ilter_to_appid\x18\x07 \x01(\x08\x12\x1f\n\x08\x61pp_list\x18\x08 \x03(\x0b\x32\r.CAppPriority\x12\x16\n\x0b\x63ount_after\x18\t \x01(\r:\x01\x30\x12\x17\n\x0c\x63ount_before\x18\n \x01(\r:\x01\x30\"W\n+CCommunity_GetUserPartnerEventNews_Response\x12(\n\x07results\x18\x01 \x03(\x0b\x32\x17.CClanMatchEventByRange\"\x8e\x01\n\'CCommunity_GetBestEventsForUser_Request\x12\x1a\n\x12include_steam_blog\x18\x01 \x01(\x08\x12$\n\x1c\x66ilter_to_played_within_days\x18\x02 \x01(\r\x12!\n\x19include_only_game_updates\x18\x03 \x01(\x08\"\xc3\x01\n\x1d\x43\x43ommunity_PartnerEventResult\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12\x18\n\x10\x61nnouncement_gid\x18\x03 \x01(\x06\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x19\n\x11possible_takeover\x18\x05 \x01(\x08\x12 \n\x15rtime32_last_modified\x18\x06 \x01(\r:\x01\x30\x12\x19\n\x11user_app_priority\x18\x07 \x01(\x05\"[\n(CCommunity_GetBestEventsForUser_Response\x12/\n\x07results\x18\x01 \x03(\x0b\x32\x1e.CCommunity_PartnerEventResult\"\xc4\x02\n+CCommunity_MarkPartnerEventsForUser_Request\x12R\n\x08markings\x18\x01 \x03(\x0b\x32@.CCommunity_MarkPartnerEventsForUser_Request.PartnerEventMarking\x1a\xc0\x01\n\x13PartnerEventMarking\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12_\n\x10\x64isplay_location\x18\x03 \x01(\x0e\x32\x1d.EPartnerEventDisplayLocation:&k_EPartnerEventDisplayLocation_Invalid\x12\x12\n\nmark_shown\x18\x04 \x01(\x08\x12\x11\n\tmark_read\x18\x05 \x01(\x08\".\n,CCommunity_MarkPartnerEventsForUser_Response\"h\n0CCommunity_GetUserPartnerEventViewStatus_Request\x12\x12\n\nevent_gids\x18\x01 \x03(\x06\x12 \n\x18include_read_events_only\x18\x02 \x01(\x08\"\xf1\x01\n1CCommunity_GetUserPartnerEventViewStatus_Response\x12O\n\x06\x65vents\x18\x01 \x03(\x0b\x32?.CCommunity_GetUserPartnerEventViewStatus_Response.PartnerEvent\x1ak\n\x0cPartnerEvent\x12\x11\n\tevent_gid\x18\x01 \x01(\x06\x12\x17\n\x0flast_shown_time\x18\x02 \x01(\r\x12\x16\n\x0elast_read_time\x18\x03 \x01(\r\x12\x17\n\x0f\x63lan_account_id\x18\x04 \x01(\r\"?\n.CCommunity_PartnerEventsShowMoreForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"1\n/CCommunity_PartnerEventsShowMoreForApp_Response\"?\n.CCommunity_PartnerEventsShowLessForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"1\n/CCommunity_PartnerEventsShowLessForApp_Response\"8\n6CCommunity_ClearUserPartnerEventsAppPriorities_Request\"9\n7CCommunity_ClearUserPartnerEventsAppPriorities_Response\"6\n4CCommunity_GetUserPartnerEventsAppPriorities_Request\"O\n#CCommunity_PartnerEventsAppPriority\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11user_app_priority\x18\x02 \x01(\x05\"q\n5CCommunity_GetUserPartnerEventsAppPriorities_Response\x12\x38\n\npriorities\x18\x01 \x03(\x0b\x32$.CCommunity_PartnerEventsAppPriority\"G\n6CCommunity_ClearSinglePartnerEventsAppPriority_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"9\n7CCommunity_ClearSinglePartnerEventsAppPriority_Response\"\xdd\x01\n3CCommunity_SetRecommendationBotReviewStatus_Request\x12W\n\rreview_labels\x18\x01 \x03(\x0b\x32@.CCommunity_SetRecommendationBotReviewStatus_Request.ReviewLabel\x1aM\n\x0bReviewLabel\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10recommendationid\x18\x02 \x01(\x04\x12\x15\n\ris_bot_review\x18\x03 \x01(\x08\"6\n4CCommunity_SetRecommendationBotReviewStatus_Response\"c\n5CCommunity_GetBotReviewScoreForRecommendation_Request\x12\x1a\n\x12recommendation_ids\x18\x01 \x03(\x04\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"\xd2\x01\n6CCommunity_GetBotReviewScoreForRecommendation_Response\x12\x65\n\x10\x62ot_review_score\x18\x01 \x03(\x0b\x32K.CCommunity_GetBotReviewScoreForRecommendation_Response.BotReviewScoreEntry\x1a\x31\n\x13\x42otReviewScoreEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\r*p\n\x0f\x45\x43lanImageGroup\x12\x1a\n\x16k_EClanImageGroup_None\x10\x00\x12\"\n\x1ek_EClanImageGroup_Announcement\x10\x01\x12\x1d\n\x19k_EClanImageGroup_Curator\x10\x02*\xe5\x02\n\x12\x45\x43lanImageFileType\x12 \n\x1ck_EClanImageFileType_Unknown\x10\x00\x12\x1d\n\x19k_EClanImageFileType_JPEG\x10\x01\x12\x1c\n\x18k_EClanImageFileType_GIF\x10\x02\x12\x1c\n\x18k_EClanImageFileType_PNG\x10\x03\x12\x1c\n\x18k_EClanImageFileType_MP4\x10\x04\x12\x1d\n\x19k_EClanImageFileType_WEBM\x10\x05\x12\x1c\n\x18k_EClanImageFileType_VTT\x10\x06\x12\x1c\n\x18k_EClanImageFileType_SRT\x10\x07\x12\x1c\n\x18k_EClanImageFileType_SVG\x10\x08\x12\x1c\n\x18k_EClanImageFileType_XML\x10\t\x12\x1d\n\x19k_EClanImageFileType_WEBP\x10\n*\xbd\x04\n\x1c\x45PartnerEventDisplayLocation\x12*\n&k_EPartnerEventDisplayLocation_Invalid\x10\x00\x12\x36\n2k_EPartnerEventDisplayLocation_AppDetailsSpotlight\x10\x01\x12\x32\n.k_EPartnerEventDisplayLocation_LibraryOverview\x10\x02\x12/\n+k_EPartnerEventDisplayLocation_StoreAppPage\x10\x03\x12\x30\n,k_EPartnerEventDisplayLocation_EventScroller\x10\x04\x12\x35\n1k_EPartnerEventDisplayLocation_AppDetailsActivity\x10\x05\x12/\n+k_EPartnerEventDisplayLocation_CommunityHub\x10\x06\x12\x31\n-k_EPartnerEventDisplayLocation_StoreFrontPage\x10\x07\x12*\n&k_EPartnerEventDisplayLocation_NewsHub\x10\x08\x12.\n*k_EPartnerEventDisplayLocation_GamepadHome\x10\t\x12+\n\'k_EPartnerEventDisplayLocation_StoreHub\x10\n2\x88\x19\n\tCommunity\x12\x44\n\x07GetApps\x12\x1b.CCommunity_GetApps_Request\x1a\x1c.CCommunity_GetApps_Response\x12\x89\x01\n\x1eGetAppRichPresenceLocalization\x12\x32.CCommunity_GetAppRichPresenceLocalization_Request\x1a\x33.CCommunity_GetAppRichPresenceLocalization_Response\x12_\n\x10GetCommentThread\x12$.CCommunity_GetCommentThread_Request\x1a%.CCommunity_GetCommentThread_Response\x12h\n\x13PostCommentToThread\x12\'.CCommunity_PostCommentToThread_Request\x1a(.CCommunity_PostCommentToThread_Response\x12t\n\x17\x44\x65leteCommentFromThread\x12+.CCommunity_DeleteCommentFromThread_Request\x1a,.CCommunity_DeleteCommentFromThread_Response\x12\x62\n\x11RateCommentThread\x12%.CCommunity_RateCommentThread_Request\x1a&.CCommunity_RateCommentThread_Response\x12t\n\x17GetCommentThreadRatings\x12+.CCommunity_GetCommentThreadRatings_Request\x1a,.CCommunity_GetCommentThreadRatings_Response\x12k\n\x14RateClanAnnouncement\x12(.CCommunity_RateClanAnnouncement_Request\x1a).CCommunity_RateClanAnnouncement_Response\x12\x89\x01\n\x1eGetClanAnnouncementVoteForUser\x12\x32.CCommunity_GetClanAnnouncementVoteForUser_Request\x1a\x33.CCommunity_GetClanAnnouncementVoteForUser_Response\x12n\n\x15GetClanLocGroupImages\x12).CCommunity_GetClanLocGroupImages_Request\x1a*.CCommunity_GetClanLocGroupImages_Response\x12_\n\x10GetAvatarHistory\x12$.CCommunity_GetAvatarHistory_Request\x1a%.CCommunity_GetAvatarHistory_Response\x12\x80\x01\n\x1bGetClanEventCrowdInMetadata\x12/.CCommunity_GetClanEventCrowdInMetadata_Request\x1a\x30.CCommunity_GetClanEventCrowdInMetadata_Response\x12q\n\x16GetClanCrowdInMetadata\x12*.CCommunity_GetClanCrowdInMetadata_Request\x1a+.CCommunity_GetClanCrowdInMetadata_Response\x12\x80\x01\n\x1b\x46\x65tchTranslationFromCrowdIn\x12/.CCommunity_FetchTranslationFromCrowdIn_Request\x1a\x30.CCommunity_FetchTranslationFromCrowdIn_Response\x12k\n\x14HideAndReportComment\x12(.CCommunity_HideAndReportComment_Request\x1a).CCommunity_HideAndReportComment_Response\x12t\n\x17GetUserPartnerEventNews\x12+.CCommunity_GetUserPartnerEventNews_Request\x1a,.CCommunity_GetUserPartnerEventNews_Response\x12k\n\x14GetBestEventsForUser\x12(.CCommunity_GetBestEventsForUser_Request\x1a).CCommunity_GetBestEventsForUser_Response\x12w\n\x18MarkPartnerEventsForUser\x12,.CCommunity_MarkPartnerEventsForUser_Request\x1a-.CCommunity_MarkPartnerEventsForUser_Response\x12\x86\x01\n\x1dGetUserPartnerEventViewStatus\x12\x31.CCommunity_GetUserPartnerEventViewStatus_Request\x1a\x32.CCommunity_GetUserPartnerEventViewStatus_Response\x12\x80\x01\n\x1bPartnerEventsShowMoreForApp\x12/.CCommunity_PartnerEventsShowMoreForApp_Request\x1a\x30.CCommunity_PartnerEventsShowMoreForApp_Response\x12\x80\x01\n\x1bPartnerEventsShowLessForApp\x12/.CCommunity_PartnerEventsShowLessForApp_Request\x1a\x30.CCommunity_PartnerEventsShowLessForApp_Response\x12\x98\x01\n#ClearUserPartnerEventsAppPriorities\x12\x37.CCommunity_ClearUserPartnerEventsAppPriorities_Request\x1a\x38.CCommunity_ClearUserPartnerEventsAppPriorities_Response\x12\x92\x01\n!GetUserPartnerEventsAppPriorities\x12\x35.CCommunity_GetUserPartnerEventsAppPriorities_Request\x1a\x36.CCommunity_GetUserPartnerEventsAppPriorities_Response\x12\x98\x01\n#ClearSinglePartnerEventsAppPriority\x12\x37.CCommunity_ClearSinglePartnerEventsAppPriority_Request\x1a\x38.CCommunity_ClearSinglePartnerEventsAppPriority_Response\x12\x8f\x01\n SetRecommendationBotReviewStatus\x12\x34.CCommunity_SetRecommendationBotReviewStatus_Request\x1a\x35.CCommunity_SetRecommendationBotReviewStatus_Response\x12\x95\x01\n\"GetBotReviewScoreForRecommendation\x12\x36.CCommunity_GetBotReviewScoreForRecommendation_Request\x1a\x37.CCommunity_GetBotReviewScoreForRecommendation_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_community_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _ECLANIMAGEGROUP._serialized_start=8050
  _ECLANIMAGEGROUP._serialized_end=8162
  _ECLANIMAGEFILETYPE._serialized_start=8165
  _ECLANIMAGEFILETYPE._serialized_end=8522
  _EPARTNEREVENTDISPLAYLOCATION._serialized_start=8525
  _EPARTNEREVENTDISPLAYLOCATION._serialized_end=9098
  _CCOMMUNITY_GETAPPS_REQUEST._serialized_start=106
  _CCOMMUNITY_GETAPPS_REQUEST._serialized_end=168
  _CCOMMUNITY_GETAPPS_RESPONSE._serialized_start=170
  _CCOMMUNITY_GETAPPS_RESPONSE._serialized_end=236
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST._serialized_start=238
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST._serialized_end=322
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE._serialized_start=325
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE._serialized_end=620
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN._serialized_start=478
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN._serialized_end=514
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST._serialized_start=516
  _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST._serialized_end=620
  _CCOMMUNITY_GETCOMMENTTHREAD_REQUEST._serialized_start=623
  _CCOMMUNITY_GETCOMMENTTHREAD_REQUEST._serialized_end=958
  _CCOMMUNITY_COMMENT._serialized_start=961
  _CCOMMUNITY_COMMENT._serialized_end=1329
  _CCOMMUNITY_COMMENT_REACTION._serialized_start=1284
  _CCOMMUNITY_COMMENT_REACTION._serialized_end=1329
  _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE._serialized_start=1332
  _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE._serialized_end=1794
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST._serialized_start=1797
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST._serialized_end=2087
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE._serialized_start=2089
  _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE._serialized_end=2207
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST._serialized_start=2210
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST._serialized_end=2429
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE._serialized_start=2431
  _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE._serialized_end=2476
  _CCOMMUNITY_RATECOMMENTTHREAD_REQUEST._serialized_start=2479
  _CCOMMUNITY_RATECOMMENTTHREAD_REQUEST._serialized_end=2671
  _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE._serialized_start=2674
  _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE._serialized_end=2811
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST._serialized_start=2814
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST._serialized_end=2984
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE._serialized_start=2987
  _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE._serialized_end=3143
  _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST._serialized_start=3145
  _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST._serialized_end=3251
  _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE._serialized_start=3253
  _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE._serialized_end=3295
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST._serialized_start=3297
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST._serialized_end=3372
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE._serialized_start=3374
  _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE._serialized_end=3464
  _CCOMMUNITY_GETCLANLOCGROUPIMAGES_REQUEST._serialized_start=3467
  _CCOMMUNITY_GETCLANLOCGROUPIMAGES_REQUEST._serialized_end=3624
  _CCOMMUNITY_CLANLOCGROUPIMAGE._serialized_start=3627
  _CCOMMUNITY_CLANLOCGROUPIMAGE._serialized_end=3901
  _CCOMMUNITY_GETCLANLOCGROUPIMAGES_RESPONSE._serialized_start=3903
  _CCOMMUNITY_GETCLANLOCGROUPIMAGES_RESPONSE._serialized_end=3993
  _CCOMMUNITY_GETAVATARHISTORY_REQUEST._serialized_start=3995
  _CCOMMUNITY_GETAVATARHISTORY_REQUEST._serialized_end=4084
  _CCOMMUNITY_GETAVATARHISTORY_RESPONSE._serialized_start=4087
  _CCOMMUNITY_GETAVATARHISTORY_RESPONSE._serialized_end=4269
  _CCOMMUNITY_GETAVATARHISTORY_RESPONSE_AVATARDATA._serialized_start=4194
  _CCOMMUNITY_GETAVATARHISTORY_RESPONSE_AVATARDATA._serialized_end=4269
  _CCOMMUNITY_GETCLANEVENTCROWDINMETADATA_REQUEST._serialized_start=4271
  _CCOMMUNITY_GETCLANEVENTCROWDINMETADATA_REQUEST._serialized_end=4352
  _CCOMMUNITY_GETCLANEVENTCROWDINMETADATA_RESPONSE._serialized_start=4354
  _CCOMMUNITY_GETCLANEVENTCROWDINMETADATA_RESPONSE._serialized_end=4456
  _CCOMMUNITY_GETCLANCROWDINMETADATA_REQUEST._serialized_start=4458
  _CCOMMUNITY_GETCLANCROWDINMETADATA_REQUEST._serialized_end=4518
  _CCOMMUNITY_GETCLANCROWDINMETADATA_RESPONSE._serialized_start=4520
  _CCOMMUNITY_GETCLANCROWDINMETADATA_RESPONSE._serialized_end=4647
  _CCOMMUNITY_FETCHTRANSLATIONFROMCROWDIN_REQUEST._serialized_start=4649
  _CCOMMUNITY_FETCHTRANSLATIONFROMCROWDIN_REQUEST._serialized_end=4748
  _CCOMMUNITY_FETCHTRANSLATIONFROMCROWDIN_RESPONSE._serialized_start=4750
  _CCOMMUNITY_FETCHTRANSLATIONFROMCROWDIN_RESPONSE._serialized_end=4799
  _CCOMMUNITY_HIDEANDREPORTCOMMENT_REQUEST._serialized_start=4802
  _CCOMMUNITY_HIDEANDREPORTCOMMENT_REQUEST._serialized_end=5061
  _CCOMMUNITY_HIDEANDREPORTCOMMENT_RESPONSE._serialized_start=5063
  _CCOMMUNITY_HIDEANDREPORTCOMMENT_RESPONSE._serialized_end=5105
  _CAPPPRIORITY._serialized_start=5107
  _CAPPPRIORITY._serialized_end=5154
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST._serialized_start=5157
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST._serialized_end=5471
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE._serialized_start=5473
  _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE._serialized_end=5560
  _CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST._serialized_start=5563
  _CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST._serialized_end=5705
  _CCOMMUNITY_PARTNEREVENTRESULT._serialized_start=5708
  _CCOMMUNITY_PARTNEREVENTRESULT._serialized_end=5903
  _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE._serialized_start=5905
  _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE._serialized_end=5996
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST._serialized_start=5999
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST._serialized_end=6323
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING._serialized_start=6131
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING._serialized_end=6323
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE._serialized_start=6325
  _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE._serialized_end=6371
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_REQUEST._serialized_start=6373
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_REQUEST._serialized_end=6477
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE._serialized_start=6480
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE._serialized_end=6721
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE_PARTNEREVENT._serialized_start=6614
  _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE_PARTNEREVENT._serialized_end=6721
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST._serialized_start=6723
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST._serialized_end=6786
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE._serialized_start=6788
  _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE._serialized_end=6837
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST._serialized_start=6839
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST._serialized_end=6902
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE._serialized_start=6904
  _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE._serialized_end=6953
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_start=6955
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_end=7011
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_start=7013
  _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_end=7070
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_start=7072
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST._serialized_end=7126
  _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY._serialized_start=7128
  _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY._serialized_end=7207
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_start=7209
  _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE._serialized_end=7322
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST._serialized_start=7324
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST._serialized_end=7395
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE._serialized_start=7397
  _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE._serialized_end=7454
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_REQUEST._serialized_start=7457
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_REQUEST._serialized_end=7678
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_REQUEST_REVIEWLABEL._serialized_start=7601
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_REQUEST_REVIEWLABEL._serialized_end=7678
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_RESPONSE._serialized_start=7680
  _CCOMMUNITY_SETRECOMMENDATIONBOTREVIEWSTATUS_RESPONSE._serialized_end=7734
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_REQUEST._serialized_start=7736
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_REQUEST._serialized_end=7835
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_RESPONSE._serialized_start=7838
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_RESPONSE._serialized_end=8048
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_RESPONSE_BOTREVIEWSCOREENTRY._serialized_start=7999
  _CCOMMUNITY_GETBOTREVIEWSCOREFORRECOMMENDATION_RESPONSE_BOTREVIEWSCOREENTRY._serialized_end=8048
  _COMMUNITY._serialized_start=9101
  _COMMUNITY._serialized_end=12309
_builder.BuildServices(DESCRIPTOR, 'steammessages_community_pb2', globals())
# @@protoc_insertion_point(module_scope)



"""
WebAPI provides a thin wrapper over `Steam's Web API <https://developer.valvesoftware.com/wiki/Steam_Web_API>`_

It is very friendly to exploration and prototyping when using ``ipython``, ``notebooks`` or similar.
The ``key`` will determine what WebAPI interfaces and methods are available.

.. note::
    Some endpoints don't require a key

Currently the WebAPI can be accessed via one of two API hosts. See :class:`APIHost`.

Example code:

.. code:: python

    >>> api = WebAPI(key)
    >>> api.call('ISteamUser.ResolveVanityURL', vanityurl="valve", url_type=2)
    >>> api.ISteamUser.ResolveVanityURL(vanityurl="valve", url_type=2)
    >>> api.ISteamUser.ResolveVanityURL_v1(vanityurl="valve", url_type=2)
    {'response': {'steamid': '103582791429521412', 'success': 1}}

All globals params (``key``, ``https``, ``format``, ``raw``) can be specified on per call basis.

.. code:: python

    >>> print a.ISteamUser.ResolveVanityURL(format='vdf', raw=True, vanityurl="valve", url_type=2)
    "response"
    {
            "steamid"       "103582791429521412"
            "success"       "1"
    }
"""
import json as _json
from steam.utils.web import make_requests_session as _make_session

class APIHost(object):
    """Enum of currently available API hosts."""
    Public = 'api.steampowered.com'
    """ available over HTTP (port 80) and HTTPS (port 443)"""
    Partner = 'partner.steam-api.com'
    """available over HTTPS (port 443) only

    .. note::
        Key is required for every request. If not supplied you will get HTTP 403.
    """

DEFAULT_PARAMS = {
    # api parameters
    'apihost': APIHost.Public,
    'key': None,
    'format': 'json',
    # internal
    'https': True,
    'http_timeout': 30,
    'raw': False,
}


class WebAPI(object):
    """Steam WebAPI wrapper

    .. note::
        Interfaces and methods are populated automatically from Steam WebAPI.

    :param key: api key from https://steamcommunity.com/dev/apikey
    :type key: :class:`str`
    :param format: response format, either (``json``, ``vdf``, or ``xml``) only when ``raw=False``
    :type format: :class:`str`
    :param raw: return raw response
    :type raw: class:`bool`
    :param https: use ``https``
    :type https: :class:`bool`
    :param http_timeout: HTTP timeout in seconds
    :type http_timeout: :class:`int`
    :param apihost: api hostname, see :class:`APIHost`
    :type apihost: :class:`str`
    :param auto_load_interfaces: load interfaces from the Steam WebAPI
    :type auto_load_interfaces: :class:`bool`

    These can be specified per method call for one off calls
    """
    key = DEFAULT_PARAMS['key']
    format = DEFAULT_PARAMS['format']
    raw = DEFAULT_PARAMS['raw']
    https = DEFAULT_PARAMS['https']
    http_timeout = DEFAULT_PARAMS['http_timeout']
    apihost = DEFAULT_PARAMS['apihost']
    interfaces = []

    def __init__(self, key, format = DEFAULT_PARAMS['format'],
                            raw = DEFAULT_PARAMS['raw'],
                            https = DEFAULT_PARAMS['https'],
                            http_timeout = DEFAULT_PARAMS['http_timeout'],
                            apihost = DEFAULT_PARAMS['apihost'],
                            auto_load_interfaces = True):
        self.key = key                              #: api key
        self.format = format                        #: format (``json``, ``vdf``, or ``xml``)
        self.raw = raw                              #: return raw reponse or parse
        self.https = https                          #: use https or not
        self.http_timeout = http_timeout            #: HTTP timeout in seconds
        self.apihost = apihost                      #: ..versionadded:: 0.8.3 apihost hostname
        self.interfaces = []                        #: list of all interfaces
        self.session = _make_session()              #: :class:`requests.Session` from :func:`.make_requests_session`

        if auto_load_interfaces:
            self.load_interfaces(self.fetch_interfaces())

    def __repr__(self):
        return "%s(key=%s, https=%s)" % (
            self.__class__.__name__,
            repr(self.key),
            repr(self.https),
            )

    def fetch_interfaces(self):
        """
        Returns a dict with the response from ``GetSupportedAPIList``

        :return: :class:`dict` of all interfaces and methods

        The returned value can passed to :meth:`load_interfaces`
        """
        return get('ISteamWebAPIUtil', 'GetSupportedAPIList', 1,
            https=self.https,
            apihost=self.apihost,
            caller=None,
            session=self.session,
            params={'format': 'json',
                    'key': self.key,
                    },
            )

    def load_interfaces(self, interfaces_dict):
        """
        Populates the namespace under the instance
        """
        if interfaces_dict.get('apilist', {}).get('interfaces', None) is None:
            raise ValueError("Invalid response for GetSupportedAPIList")

        interfaces = interfaces_dict['apilist']['interfaces']
        if len(interfaces) == 0:
            raise ValueError("API returned not interfaces; probably using invalid key")

        # clear existing interface instances
        for interface in self.interfaces:
            delattr(self, interface.name)
        self.interfaces = []

        # create interface instances from response
        for interface in interfaces:
            obj = WebAPIInterface(interface, parent=self)
            self.interfaces.append(obj)
            setattr(self, obj.name, obj)

    def call(self, method_path, **kwargs):
        """
        Make an API call for specific method

        :param method_path: format ``Interface.Method`` (e.g. ``ISteamWebAPIUtil.GetServerInfo``)
        :type method_path: :class:`str`
        :param kwargs: keyword arguments for the specific method
        :return: response
        :rtype: :class:`dict`, :class:`lxml.etree.Element` or :class:`str`
        """

        interface, method = method_path.split('.', 1)
        return getattr(getattr(self, interface), method)(**kwargs)


    def doc(self):
        """
        :return: Documentation for all interfaces and their methods
        :rtype: str
        """
        doc = "Steam Web API - List of all interfaces\n\n"
        for interface in self.interfaces:
            doc += interface.__doc__
        return doc


class WebAPIInterface(object):
    """
    Steam Web API Interface
    """

    def __init__(self, interface_dict, parent):
        self._parent = parent
        self.name = interface_dict['name']
        self.methods = []

        for method in interface_dict['methods']:
            obj = WebAPIMethod(method, parent=self)
            self.methods.append(obj)

            # map the method name as attribute including version
            setattr(self, "%s_v%d" % (obj.name, obj.version), obj)

            # without version, but th refernce of latest version
            current_obj = getattr(self, obj.name, None)
            if current_obj is None or current_obj.version < obj.version:
                setattr(self, obj.name, obj)

    def __repr__(self):
        return "<%s %s with %s methods>" % (
            self.__class__.__name__,
            repr(self.name),
            repr(len(list(self))),
            )

    def __iter__(self):
        return iter(self.methods)

    @property
    def key(self):
        return self._parent.key

    @property
    def apihost(self):
        return self._parent.apihost

    @property
    def https(self):
        return self._parent.https

    @property
    def http_timeout(self):
        return self._parent.http_timeout

    @property
    def format(self):
        return self._parent.format

    @property
    def raw(self):
        return self._parent.raw

    @property
    def session(self):
        return self._parent.session

    def doc(self):
        """
        :return: Documentation for all methods on this interface
        :rtype: str
        """
        return self.__doc__

    @property
    def __doc__(self):
        doc = "%s\n%s\n" % (self.name, '-'*len(self.name))
        for method in self.methods:
            doc += "  %s\n" % method.__doc__.replace("\n", "\n  ")
        return doc


class WebAPIMethod(object):
    """
    Steam Web API Interface Method
    """

    def __init__(self, method_dict, parent):
        self.last_response = None
        self._parent = parent
        self._dict = method_dict

        params = method_dict['parameters']
        self._dict['parameters'] = {}
        for param in params:
            # add property indicating param can be a list
            param['_array'] = param['name'].endswith('[0]')
            # remove array suffix
            if param['_array']:
                param['name'] = param['name'][:-3]
            # turn params from a list to a dict
            self._dict['parameters'][param['name']] = param

    def __repr__(self):
        return "<%s %s>" % (
            self.__class__.__name__,
            repr("%s.%s_v%d" % (
                self._parent.name,
                self.name,
                self.version,
                )),
            )

    def __call__(self, **kwargs):
        possible_kwargs = set(self._dict['parameters'].keys()) | set(DEFAULT_PARAMS.keys())
        unrecognized = set(kwargs.keys()).difference(possible_kwargs)
        if unrecognized:
            raise ValueError("Unrecognized parameter %s" % repr(unrecognized.pop()))

        params = {}
        # process special case kwargs
        for param in DEFAULT_PARAMS.keys():
            if param in kwargs:
                params[param] = kwargs[param]
                del kwargs[param]
            else:
                params[param] = getattr(self._parent, param)

        # process method parameters
        for param in self.parameters.values():
            name = param['name']
            islist = param['_array']
            optional = param['optional']

            if not optional and name not in kwargs and name != 'key':
                raise ValueError("Method requires %s to be set" % repr(name))

            if name in kwargs:
                if islist and not isinstance(kwargs[name], list):
                    raise ValueError("Expected %s to be a list, got %s" % (
                        repr(name),
                        repr(type(kwargs[name])))
                        )
                params[name] = kwargs[name]

        url = "%s://%s/%s/%s/v%s/" % (
            'https' if self._parent.https else 'http',
            self._parent.apihost,
            self._parent.name,
            self.name,
            self.version,
            )

        return webapi_request(
            url=url,
            method=self.method,
            caller=self,
            session=self._parent.session,
            params=params,
            )

    @property
    def version(self):
        return self._dict['version']

    @property
    def method(self):
        return self._dict['httpmethod']

    @property
    def parameters(self):
        return self._dict['parameters']

    @property
    def name(self):
        return self._dict['name']

    def doc(self):
        """
        :return: Documentation for this method
        :rtype: str
        """
        return self.__doc__

    @property
    def __doc__(self):
        doc = "%(httpmethod)s %(name)s (v%(version)04d)\n" % self._dict

        if 'description' in self._dict:
            doc += "\n  %(description)s\n" % self._dict

        if len(self.parameters):
            doc += "  \n  Parameters:\n"

            for param in sorted(self.parameters.values(), key=lambda x: x['name']):
                doc += "    %s %s %s%s\n" % (
                    param['name'].ljust(25),
                    ((param['type']+"[]") if param['_array'] else
                     param['type']
                     ).ljust(8),
                    'optional' if param['optional'] else 'required',
                    (("\n      - " + param['description'])
                     if 'description' in param and param['description'] else ''
                     ),
                    )

        return doc

def webapi_request(url, method='GET', caller=None, session=None, params=None):
    """Low level function for calling Steam's WebAPI

    .. versionchanged:: 0.8.3

    :param url: request url (e.g. ``https://api.steampowered.com/A/B/v001/``)
    :type url: :class:`str`
    :param method: HTTP method (GET or POST)
    :type method: :class:`str`
    :param caller: caller reference, caller.last_response is set to the last response
    :param params: dict of WebAPI and endpoint specific params
    :type params: :class:`dict`
    :param session: an instance requests session, or one is created per call
    :type session: :class:`requests.Session`
    :return: response based on paramers
    :rtype: :class:`dict`, :class:`lxml.etree.Element`, :class:`str`
    """
    if method not in ('GET', 'POST'):
        raise ValueError("Only GET and POST methods are supported, got: %s" % repr(method))
    if params is None:
        params = {}

    onetime = {}
    for param in DEFAULT_PARAMS:
        params[param] = onetime[param] = params.get(param, DEFAULT_PARAMS[param])
    for param in ('raw', 'apihost', 'https', 'http_timeout'):
        del params[param]

    if onetime['format'] not in ('json', 'vdf', 'xml'):
        raise ValueError("Expected format to be json,vdf or xml; got %s" % onetime['format'])

    for k, v in list(params.items()): # serialize some types
        if isinstance(v, bool): params[k] = 1 if v else 0
        elif isinstance(v, dict): params[k] = _json.dumps(v)
        elif isinstance(v, list):
            del params[k]
            for i, lvalue in enumerate(v):
                params["%s[%d]" % (k, i)] = lvalue

    kwargs = {'params': params} if method == "GET" else {'data': params} # params to data for POST

    if session is None: session = _make_session()

    f = getattr(session, method.lower())
    resp = f(url, stream=False, timeout=onetime['http_timeout'], **kwargs)

    # we keep a reference of the last response instance on the caller
    if caller is not None: caller.last_response = resp
    # 4XX and 5XX will cause this to raise
    resp.raise_for_status()

    if onetime['raw']:
        return resp.text
    elif onetime['format'] == 'json':
        return resp.json()
    elif onetime['format'] == 'xml':
        from lxml import etree as _etree
        return _etree.fromstring(resp.content)
    elif onetime['format'] == 'vdf':
        import vdf as _vdf
        return _vdf.loads(resp.text)

def get(interface, method, version=1,
        apihost=DEFAULT_PARAMS['apihost'], https=DEFAULT_PARAMS['https'],
        caller=None, session=None, params=None):
    """Send GET request to an API endpoint

    .. versionadded:: 0.8.3

    :param interface: interface name
    :type interface: str
    :param method: method name
    :type method: str
    :param version: method version
    :type version: int
    :param apihost: API hostname
    :type apihost: str
    :param https: whether to use HTTPS
    :type https: bool
    :param params: parameters for endpoint
    :type params: dict
    :return: endpoint response
    :rtype: :class:`dict`, :class:`lxml.etree.Element`, :class:`str`
    """
    url = u"%s://%s/%s/%s/v%s/" % (
        'https' if https else 'http', apihost, interface, method, version)
    return webapi_request(url, 'GET', caller=caller, session=session, params=params)

def post(interface, method, version=1,
         apihost=DEFAULT_PARAMS['apihost'], https=DEFAULT_PARAMS['https'],
         caller=None, session=None, params=None):
    """Send POST request to an API endpoint

    .. versionadded:: 0.8.3

    :param interface: interface name
    :type interface: str
    :param method: method name
    :type method: str
    :param version: method version
    :type version: int
    :param apihost: API hostname
    :type apihost: str
    :param https: whether to use HTTPS
    :type https: bool
    :param params: parameters for endpoint
    :type params: dict
    :return: endpoint response
    :rtype: :class:`dict`, :class:`lxml.etree.Element`, :class:`str`
    """
    url = "%s://%s/%s/%s/v%s/" % (
        'https' if https else 'http', apihost, interface, method, version)
    return webapi_request(url, 'POST', caller=caller, session=session, params=params)



import requests
from binascii import hexlify
from steam.core.crypto import sha1_hash, random_bytes

def make_requests_session():
    """
    :returns: requests session
    :rtype: :class:`requests.Session`
    """
    session = requests.Session()

    version = __import__('steam').__version__
    ua = "python-steam/{0} {1}".format(version,
                                session.headers['User-Agent'])
    session.headers['User-Agent'] = ua

    return session

def generate_session_id():
    """
    :returns: session id
    :rtype: :class:`str`
    """
    return hexlify(sha1_hash(random_bytes(32)))[:32].decode('ascii')



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_siteserverui.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_siteserverui.proto\x1a\x18steammessages_base.proto\"s\n\x1aSiteServerUI_Login_Request\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x16\n\x0esteamguardcode\x18\x03 \x01(\t\x12\x19\n\x11remember_password\x18\x04 \x01(\x08\"I\n\x1bSiteServerUI_Login_Response\x12\x13\n\x0blogon_state\x18\x01 \x01(\x05\x12\x15\n\rlogon_eresult\x18\x02 \x01(\x05\"\"\n SiteServerUI_LoginStatus_Request\"}\n!SiteServerUI_LoginStatus_Response\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x1a\n\x12\x63\x61\x63hed_credentials\x18\x02 \x01(\x08\x12\x13\n\x0blogon_state\x18\x03 \x01(\x05\x12\x15\n\rlogon_eresult\x18\x04 \x01(\x05\"\"\n SiteServerUI_CancelLogin_Request\"O\n!SiteServerUI_CancelLogin_Response\x12\x13\n\x0blogon_state\x18\x01 \x01(\x05\x12\x15\n\rlogon_eresult\x18\x02 \x01(\x05\"\x1d\n\x1bSiteServerUI_Logout_Request\"K\n\x1cSiteServerUI_Logout_Response\x12\x13\n\x0blogon_state\x18\x01 \x01(\x05\x12\x16\n\x0elogout_eresult\x18\x02 \x01(\x05\",\n\x19SiteServerUI_Quit_Request\x12\x0f\n\x07restart\x18\x01 \x01(\x08\"\x1c\n\x1aSiteServerUI_Quit_Response\"\x1d\n\x1bSiteServerUI_Status_Request\"\x89\x01\n\x1cSiteServerUI_Status_Response\x12\x13\n\x0blogon_state\x18\x01 \x01(\x05\x12\x15\n\rlogon_eresult\x18\x02 \x01(\x05\x12\x11\n\tconnected\x18\x03 \x01(\x08\x12\x15\n\rcache_enabled\x18\x04 \x01(\x08\x12\x13\n\x0b\x61\x63\x63t_status\x18\x05 \x01(\x05\"\"\n SiteServerUI_GetLanguage_Request\"5\n!SiteServerUI_GetLanguage_Response\x12\x10\n\x08language\x18\x01 \x01(\t\"4\n SiteServerUI_SetLanguage_Request\x12\x10\n\x08language\x18\x01 \x01(\t\"#\n!SiteServerUI_SetLanguage_Response\"#\n!SiteServerUI_ClientStatus_Request\"\xb6\x03\n\"SiteServerUI_ClientStatus_Response\x12?\n\x07\x63lients\x18\x04 \x03(\x0b\x32..SiteServerUI_ClientStatus_Response.ClientInfo\x12=\n\x08payments\x18\x05 \x03(\x0b\x32+.SiteServerUI_ClientStatus_Response.Payment\x1aR\n\nClientInfo\x12\n\n\x02ip\x18\x01 \x01(\r\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x11\n\tconnected\x18\x03 \x01(\x08\x12\x13\n\x0binstance_id\x18\x04 \x01(\x04\x1a\xbb\x01\n\x07Payment\x12\x0f\n\x07transid\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\x12\x14\n\x0ctime_created\x18\x04 \x01(\x05\x12\x17\n\x0fpurchase_status\x18\x05 \x01(\x05\x12\x10\n\x08hostname\x18\x06 \x01(\t\x12\x14\n\x0cpersona_name\x18\x07 \x01(\t\x12\x13\n\x0bprofile_url\x18\x08 \x01(\t\x12\x12\n\navatar_url\x18\t \x01(\t\")\n\'SiteServerUI_ContentCacheStatus_Request\"\x8b\x02\n(SiteServerUI_ContentCacheStatus_Response\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x16\n\x0e\x63\x61\x63he_location\x18\x03 \x01(\t\x12\x13\n\x0bmax_size_gb\x18\x04 \x01(\r\x12\x13\n\x0bp2p_enabled\x18\x05 \x01(\x08\x12\x1b\n\x13\x65xplicit_ip_address\x18\t \x01(\t\x12\x18\n\x10\x65xternal_process\x18\n \x01(\x08\x12\x17\n\x0f\x63urrent_size_gb\x18\x06 \x01(\r\x12\x12\n\ncurrent_bw\x18\x07 \x01(\x04\x12\x1a\n\x12total_bytes_served\x18\x08 \x01(\x04\"\xc1\x01\n\'SiteServerUI_ContentCacheConfig_Request\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x16\n\x0e\x63\x61\x63he_location\x18\x03 \x01(\t\x12\x13\n\x0bmax_size_gb\x18\x04 \x01(\r\x12\x13\n\x0bp2p_enabled\x18\x05 \x01(\x08\x12\x18\n\x10\x65xternal_process\x18\x06 \x01(\x08\x12\x1b\n\x13\x65xplicit_ip_address\x18\x07 \x01(\t\"*\n(SiteServerUI_ContentCacheConfig_ResponseB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_siteserverui_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _SITESERVERUI_LOGIN_REQUEST._serialized_start=62
  _SITESERVERUI_LOGIN_REQUEST._serialized_end=177
  _SITESERVERUI_LOGIN_RESPONSE._serialized_start=179
  _SITESERVERUI_LOGIN_RESPONSE._serialized_end=252
  _SITESERVERUI_LOGINSTATUS_REQUEST._serialized_start=254
  _SITESERVERUI_LOGINSTATUS_REQUEST._serialized_end=288
  _SITESERVERUI_LOGINSTATUS_RESPONSE._serialized_start=290
  _SITESERVERUI_LOGINSTATUS_RESPONSE._serialized_end=415
  _SITESERVERUI_CANCELLOGIN_REQUEST._serialized_start=417
  _SITESERVERUI_CANCELLOGIN_REQUEST._serialized_end=451
  _SITESERVERUI_CANCELLOGIN_RESPONSE._serialized_start=453
  _SITESERVERUI_CANCELLOGIN_RESPONSE._serialized_end=532
  _SITESERVERUI_LOGOUT_REQUEST._serialized_start=534
  _SITESERVERUI_LOGOUT_REQUEST._serialized_end=563
  _SITESERVERUI_LOGOUT_RESPONSE._serialized_start=565
  _SITESERVERUI_LOGOUT_RESPONSE._serialized_end=640
  _SITESERVERUI_QUIT_REQUEST._serialized_start=642
  _SITESERVERUI_QUIT_REQUEST._serialized_end=686
  _SITESERVERUI_QUIT_RESPONSE._serialized_start=688
  _SITESERVERUI_QUIT_RESPONSE._serialized_end=716
  _SITESERVERUI_STATUS_REQUEST._serialized_start=718
  _SITESERVERUI_STATUS_REQUEST._serialized_end=747
  _SITESERVERUI_STATUS_RESPONSE._serialized_start=750
  _SITESERVERUI_STATUS_RESPONSE._serialized_end=887
  _SITESERVERUI_GETLANGUAGE_REQUEST._serialized_start=889
  _SITESERVERUI_GETLANGUAGE_REQUEST._serialized_end=923
  _SITESERVERUI_GETLANGUAGE_RESPONSE._serialized_start=925
  _SITESERVERUI_GETLANGUAGE_RESPONSE._serialized_end=978
  _SITESERVERUI_SETLANGUAGE_REQUEST._serialized_start=980
  _SITESERVERUI_SETLANGUAGE_REQUEST._serialized_end=1032
  _SITESERVERUI_SETLANGUAGE_RESPONSE._serialized_start=1034
  _SITESERVERUI_SETLANGUAGE_RESPONSE._serialized_end=1069
  _SITESERVERUI_CLIENTSTATUS_REQUEST._serialized_start=1071
  _SITESERVERUI_CLIENTSTATUS_REQUEST._serialized_end=1106
  _SITESERVERUI_CLIENTSTATUS_RESPONSE._serialized_start=1109
  _SITESERVERUI_CLIENTSTATUS_RESPONSE._serialized_end=1547
  _SITESERVERUI_CLIENTSTATUS_RESPONSE_CLIENTINFO._serialized_start=1275
  _SITESERVERUI_CLIENTSTATUS_RESPONSE_CLIENTINFO._serialized_end=1357
  _SITESERVERUI_CLIENTSTATUS_RESPONSE_PAYMENT._serialized_start=1360
  _SITESERVERUI_CLIENTSTATUS_RESPONSE_PAYMENT._serialized_end=1547
  _SITESERVERUI_CONTENTCACHESTATUS_REQUEST._serialized_start=1549
  _SITESERVERUI_CONTENTCACHESTATUS_REQUEST._serialized_end=1590
  _SITESERVERUI_CONTENTCACHESTATUS_RESPONSE._serialized_start=1593
  _SITESERVERUI_CONTENTCACHESTATUS_RESPONSE._serialized_end=1860
  _SITESERVERUI_CONTENTCACHECONFIG_REQUEST._serialized_start=1863
  _SITESERVERUI_CONTENTCACHECONFIG_REQUEST._serialized_end=2056
  _SITESERVERUI_CONTENTCACHECONFIG_RESPONSE._serialized_start=2058
  _SITESERVERUI_CONTENTCACHECONFIG_RESPONSE._serialized_end=2100
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_contentsystem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_contentsystem.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"i\n4CContentServerDirectory_ConnectedSteamPipeServerInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x05\x12\x10\n\x08hostname\x18\x03 \x01(\t\"\xfa\x01\n6CContentServerDirectory_GetServersForSteamPipe_Request\x12\x0f\n\x07\x63\x65ll_id\x18\x01 \x01(\r\x12\x17\n\x0bmax_servers\x18\x02 \x01(\r:\x02\x32\x30\x12\x13\n\x0bip_override\x18\x03 \x01(\t\x12\x18\n\rlauncher_type\x18\x04 \x01(\x05:\x01\x30\x12\x13\n\x0bipv6_public\x18\x05 \x01(\t\x12R\n\x13\x63urrent_connections\x18\x06 \x03(\x0b\x32\x35.CContentServerDirectory_ConnectedSteamPipeServerInfo\"\xf9\x02\n\"CContentServerDirectory_ServerInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x03 \x01(\x05\x12\x0c\n\x04load\x18\x04 \x01(\x05\x12\x15\n\rweighted_load\x18\x05 \x01(\x02\x12\"\n\x1anum_entries_in_client_list\x18\x06 \x01(\x05\x12\x18\n\x10steam_china_only\x18\x07 \x01(\x08\x12\x0c\n\x04host\x18\x08 \x01(\t\x12\r\n\x05vhost\x18\t \x01(\t\x12\x14\n\x0cuse_as_proxy\x18\n \x01(\x08\x12#\n\x1bproxy_request_path_template\x18\x0b \x01(\t\x12\x15\n\rhttps_support\x18\x0c \x01(\t\x12\x17\n\x0f\x61llowed_app_ids\x18\r \x03(\r\x12\x16\n\x0epriority_class\x18\x0f \x01(\r\x12\x1e\n\x16\x62ypass_proxies_of_type\x18\x10 \x03(\t\"\x82\x01\n7CContentServerDirectory_GetServersForSteamPipe_Response\x12\x34\n\x07servers\x18\x01 \x03(\x0b\x32#.CContentServerDirectory_ServerInfo\x12\x11\n\tno_change\x18\x02 \x01(\x08\"\x89\x01\n1CContentServerDirectory_GetDepotPatchInfo_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x19\n\x11source_manifestid\x18\x03 \x01(\x04\x12\x19\n\x11target_manifestid\x18\x04 \x01(\x04\"{\n2CContentServerDirectory_GetDepotPatchInfo_Response\x12\x14\n\x0cis_available\x18\x01 \x01(\x08\x12\x12\n\npatch_size\x18\x02 \x01(\x04\x12\x1b\n\x13patched_chunks_size\x18\x03 \x01(\x04\"P\n4CContentServerDirectory_GetClientUpdateHosts_Request\x12\x18\n\x10\x63\x61\x63hed_signature\x18\x01 \x01(\t\"w\n5CContentServerDirectory_GetClientUpdateHosts_Response\x12\x10\n\x08hosts_kv\x18\x01 \x01(\t\x12\x18\n\x10valid_until_time\x18\x02 \x01(\x04\x12\x12\n\nip_country\x18\x03 \x01(\t\"\xa1\x01\n6CContentServerDirectory_GetManifestRequestCode_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x04\x12\x12\n\napp_branch\x18\x04 \x01(\t\x12\x1c\n\x14\x62ranch_password_hash\x18\x05 \x01(\t\"X\n7CContentServerDirectory_GetManifestRequestCode_Response\x12\x1d\n\x15manifest_request_code\x18\x01 \x01(\x04\"f\n/CContentServerDirectory_GetCDNAuthToken_Request\x12\x10\n\x08\x64\x65pot_id\x18\x01 \x01(\r\x12\x11\n\thost_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"Z\n0CContentServerDirectory_GetCDNAuthToken_Response\x12\r\n\x05token\x18\x01 \x01(\t\x12\x17\n\x0f\x65xpiration_time\x18\x02 \x01(\r\"\xb0\x01\n8CContentServerDirectory_RequestPeerContentServer_Request\x12\x18\n\x10remote_client_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x1f\n\x17server_remote_client_id\x18\x03 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\r\x12\x18\n\x10\x63urrent_build_id\x18\x05 \x01(\r\"\x80\x01\n9CContentServerDirectory_RequestPeerContentServer_Response\x12\x13\n\x0bserver_port\x18\x01 \x01(\r\x12\x18\n\x10installed_depots\x18\x02 \x03(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\x04\"\x80\x01\n2CContentServerDirectory_GetPeerContentInfo_Request\x12\x18\n\x10remote_client_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x1f\n\x17server_remote_client_id\x18\x03 \x01(\x04\"X\n3CContentServerDirectory_GetPeerContentInfo_Response\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r\x12\x11\n\tip_public\x18\x02 \x01(\t\"\x8d\x01\n7CDepotContentDetection_GetAllDetectedAppContent_Request\x12R\n\x0e\x64\x65tection_type\x18\x01 \x01(\x0e\x32\x19.EAppContentDetectionType:\x1fk_EAppContentDetectionType_None\"P\n\x12\x44\x65tectedAppContent\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x18\n\x10\x64\x65tected_content\x18\x03 \x01(\x05\"m\n8CDepotContentDetection_GetAllDetectedAppContent_Response\x12\x31\n\x14\x64\x65tected_app_content\x18\x01 \x03(\x0b\x32\x13.DetectedAppContent\"K\n:CDepotContentDetection_GetDetectedContentSingleApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xd2\x01\n;CDepotContentDetection_GetDetectedContentSingleApp_Response\x12G\n\x12\x64\x65tected_anticheat\x18\x01 \x01(\x0e\x32\x12.EAppAntiCheatType:\x17k_EAppAntiCheatTypeNone\x12J\n\x13\x64\x65tected_gameengine\x18\x02 \x01(\x0e\x32\x13.EAppGameEngineType:\x18k_EAppGameEngineTypeNone*\x94\x01\n\x18\x45\x41ppContentDetectionType\x12#\n\x1fk_EAppContentDetectionType_None\x10\x00\x12(\n$k_EAppContentDetectionType_AntiCheat\x10\x01\x12)\n%k_EAppContentDetectionType_GameEngine\x10\x02*\xfa\x02\n\x11\x45\x41ppAntiCheatType\x12\x1b\n\x17k_EAppAntiCheatTypeNone\x10\x00\x12\x1d\n\x19k_EAppAntiCheatTypeEasyAC\x10\x01\x12\x1d\n\x19k_EAppAntiCheatTypeDenuvo\x10\x02\x12\x1f\n\x1bk_EAppAntiCheatTypeBattlEye\x10\x03\x12\x1f\n\x1bk_EAppAntiCheatTypeXignCode\x10\x04\x12!\n\x1dk_EAppAntiCheatTypePunkBuster\x10\x05\x12\x1a\n\x16k_EAppAntiCheatTypeVAC\x10\x06\x12 \n\x1ck_EAppAntiCheatTypeGameGuard\x10\x07\x12!\n\x1dk_EAppAntiCheatTypeHackShield\x10\x08\x12&\n\"k_EAppAntiCheatTypeAntiCheatExpert\x10\t\x12\x1c\n\x18k_EAppAntiCheatTypeOther\x10\n*R\n\x12\x45\x41ppGameEngineType\x12\x1c\n\x18k_EAppGameEngineTypeNone\x10\x00\x12\x1e\n\x1ak_EAppGameEngineTypeUnreal\x10\x01\x32\xc7\x07\n\x16\x43ontentServerDirectory\x12\x8b\x01\n\x16GetServersForSteamPipe\x12\x37.CContentServerDirectory_GetServersForSteamPipe_Request\x1a\x38.CContentServerDirectory_GetServersForSteamPipe_Response\x12|\n\x11GetDepotPatchInfo\x12\x32.CContentServerDirectory_GetDepotPatchInfo_Request\x1a\x33.CContentServerDirectory_GetDepotPatchInfo_Response\x12\x85\x01\n\x14GetClientUpdateHosts\x12\x35.CContentServerDirectory_GetClientUpdateHosts_Request\x1a\x36.CContentServerDirectory_GetClientUpdateHosts_Response\x12\x8b\x01\n\x16GetManifestRequestCode\x12\x37.CContentServerDirectory_GetManifestRequestCode_Request\x1a\x38.CContentServerDirectory_GetManifestRequestCode_Response\x12v\n\x0fGetCDNAuthToken\x12\x30.CContentServerDirectory_GetCDNAuthToken_Request\x1a\x31.CContentServerDirectory_GetCDNAuthToken_Response\x12\x91\x01\n\x18RequestPeerContentServer\x12\x39.CContentServerDirectory_RequestPeerContentServer_Request\x1a:.CContentServerDirectory_RequestPeerContentServer_Response\x12\x7f\n\x12GetPeerContentInfo\x12\x33.CContentServerDirectory_GetPeerContentInfo_Request\x1a\x34.CContentServerDirectory_GetPeerContentInfo_Response2\xc4\x02\n\x15\x44\x65potContentDetection\x12\x8f\x01\n\x18GetAllDetectedAppContent\x12\x38.CDepotContentDetection_GetAllDetectedAppContent_Request\x1a\x39.CDepotContentDetection_GetAllDetectedAppContent_Response\x12\x98\x01\n\x1bGetDetectedContentSingleApp\x12;.CDepotContentDetection_GetDetectedContentSingleApp_Request\x1a<.CDepotContentDetection_GetDetectedContentSingleApp_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_contentsystem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EAPPCONTENTDETECTIONTYPE._serialized_start=3047
  _EAPPCONTENTDETECTIONTYPE._serialized_end=3195
  _EAPPANTICHEATTYPE._serialized_start=3198
  _EAPPANTICHEATTYPE._serialized_end=3576
  _EAPPGAMEENGINETYPE._serialized_start=3578
  _EAPPGAMEENGINETYPE._serialized_end=3660
  _CCONTENTSERVERDIRECTORY_CONNECTEDSTEAMPIPESERVERINFO._serialized_start=97
  _CCONTENTSERVERDIRECTORY_CONNECTEDSTEAMPIPESERVERINFO._serialized_end=202
  _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST._serialized_start=205
  _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST._serialized_end=455
  _CCONTENTSERVERDIRECTORY_SERVERINFO._serialized_start=458
  _CCONTENTSERVERDIRECTORY_SERVERINFO._serialized_end=835
  _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE._serialized_start=838
  _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE._serialized_end=968
  _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST._serialized_start=971
  _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST._serialized_end=1108
  _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE._serialized_start=1110
  _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE._serialized_end=1233
  _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST._serialized_start=1235
  _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST._serialized_end=1315
  _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE._serialized_start=1317
  _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE._serialized_end=1436
  _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST._serialized_start=1439
  _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST._serialized_end=1600
  _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE._serialized_start=1602
  _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE._serialized_end=1690
  _CCONTENTSERVERDIRECTORY_GETCDNAUTHTOKEN_REQUEST._serialized_start=1692
  _CCONTENTSERVERDIRECTORY_GETCDNAUTHTOKEN_REQUEST._serialized_end=1794
  _CCONTENTSERVERDIRECTORY_GETCDNAUTHTOKEN_RESPONSE._serialized_start=1796
  _CCONTENTSERVERDIRECTORY_GETCDNAUTHTOKEN_RESPONSE._serialized_end=1886
  _CCONTENTSERVERDIRECTORY_REQUESTPEERCONTENTSERVER_REQUEST._serialized_start=1889
  _CCONTENTSERVERDIRECTORY_REQUESTPEERCONTENTSERVER_REQUEST._serialized_end=2065
  _CCONTENTSERVERDIRECTORY_REQUESTPEERCONTENTSERVER_RESPONSE._serialized_start=2068
  _CCONTENTSERVERDIRECTORY_REQUESTPEERCONTENTSERVER_RESPONSE._serialized_end=2196
  _CCONTENTSERVERDIRECTORY_GETPEERCONTENTINFO_REQUEST._serialized_start=2199
  _CCONTENTSERVERDIRECTORY_GETPEERCONTENTINFO_REQUEST._serialized_end=2327
  _CCONTENTSERVERDIRECTORY_GETPEERCONTENTINFO_RESPONSE._serialized_start=2329
  _CCONTENTSERVERDIRECTORY_GETPEERCONTENTINFO_RESPONSE._serialized_end=2417
  _CDEPOTCONTENTDETECTION_GETALLDETECTEDAPPCONTENT_REQUEST._serialized_start=2420
  _CDEPOTCONTENTDETECTION_GETALLDETECTEDAPPCONTENT_REQUEST._serialized_end=2561
  _DETECTEDAPPCONTENT._serialized_start=2563
  _DETECTEDAPPCONTENT._serialized_end=2643
  _CDEPOTCONTENTDETECTION_GETALLDETECTEDAPPCONTENT_RESPONSE._serialized_start=2645
  _CDEPOTCONTENTDETECTION_GETALLDETECTEDAPPCONTENT_RESPONSE._serialized_end=2754
  _CDEPOTCONTENTDETECTION_GETDETECTEDCONTENTSINGLEAPP_REQUEST._serialized_start=2756
  _CDEPOTCONTENTDETECTION_GETDETECTEDCONTENTSINGLEAPP_REQUEST._serialized_end=2831
  _CDEPOTCONTENTDETECTION_GETDETECTEDCONTENTSINGLEAPP_RESPONSE._serialized_start=2834
  _CDEPOTCONTENTDETECTION_GETDETECTEDCONTENTSINGLEAPP_RESPONSE._serialized_end=3044
  _CONTENTSERVERDIRECTORY._serialized_start=3663
  _CONTENTSERVERDIRECTORY._serialized_end=4630
  _DEPOTCONTENTDETECTION._serialized_start=4633
  _DEPOTCONTENTDETECTION._serialized_end=4957
_builder.BuildServices(DESCRIPTOR, 'steammessages_contentsystem_pb2', globals())
# @@protoc_insertion_point(module_scope)



"""Utility package with various useful functions
"""
import six
from six.moves import xrange as _range
import sys

if six.PY2 and sys.platform == 'win32':
    import win_inet_pton

import weakref
import struct
import socket


def ip4_from_int(ip):
    """Convert :py:class:`int` to IPv4 string

    :param ip: int representing an IPv4
    :type ip: int
    :return: IP in dot-decimal notation
    :rtype: str
    """
    return socket.inet_ntoa(struct.pack(">L", ip))

def ip4_to_int(ip):
    """Convert IPv4 string to :py:class:`int`

    :param ip: IPv4 in dot-decimal notation
    :type ip: str
    :rtype: int
    """
    return struct.unpack(">L", socket.inet_aton(ip))[0]

ip_to_int = ip4_to_int
ip_from_int = ip4_from_int

def ip6_from_bytes(ip):
    """Convert :py:class:`bytes` to IPv6 string

    :param ip: IPv6 in dot-decimal notation
    :type ip: bytes
    :rtype: str
    """
    return socket.inet_ntop(socket.AF_INET6, ip)

def ip6_to_bytes(ip):
    """Convert IPv6 string to :py:class:`bytes`

    :param ip: IPv6 in dot-decimal notation
    :type ip: str
    :rtype: bytes
    """
    return socket.inet_pton(socket.AF_INET6, ip)


def chunks(arr, size):
    """Splits a list into chunks

    :param arr: list to split
    :type arr: :class:`list`
    :param size: number of elements in each chunk
    :type size: :class:`int`
    :return: generator object
    :rtype: :class:`generator`
    """
    for i in _range(0, len(arr), size):
        yield arr[i:i+size]


class WeakRefKeyDict(object):
    """Pretends to be a dictionary.
    Use any object (even unhashable) as key and store a value.
    Once the object is garbage collected, the entry is destroyed automatically.
    """
    def __init__(self):
        self.refs = {}

    def __setitem__(self, obj, value):
        key = id(obj)

        if key not in self.refs:
            wr = weakref.ref(obj, WeakRefCallback(self.refs, key))
            self.refs[key] = [wr, None]
        self.refs[key][1] = value

    def __getitem__(self, obj):
        key = id(obj)
        return self.refs[key][1]

    def __contains__(self, obj):
        return id(obj) in self.refs

    def __len__(self):
        return len(self.refs)

class WeakRefCallback(object):
    def __init__(self, refs, key):
        self.__dict__.update(locals())
    def __call__(self, wr):
        del self.refs[self.key]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_gamerecording.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_clientserver_video_pb2 as steammessages__clientserver__video__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_gamerecording.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a&steammessages_clientserver_video.proto\"\xb4\x01\n\x13\x43VideoManagerClipID\x12\x1d\n\x15video_manager_clip_id\x18\x01 \x01(\x06\x12\x1e\n\x16video_manager_video_id\x18\x02 \x01(\x06\x12\x1a\n\x12server_timeline_id\x18\x03 \x01(\x06\x12\x14\n\x0cmanifest_url\x18\x04 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\x05 \x01(\r\x12\x17\n\x0fstart_offset_ms\x18\x06 \x01(\r\"\xd9\x01\n\x12\x43GameRecordingClip\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\x06\x12\x0e\n\x06gameid\x18\x02 \x01(\x04\x12\x15\n\rdate_recorded\x18\x04 \x01(\r\x12\x1d\n\x15total_file_size_bytes\x18\x07 \x01(\x04\x12\'\n\tvideo_ids\x18\t \x03(\x0b\x32\x14.CVideoManagerClipID\x12\x15\n\rowner_steamid\x18\n \x01(\x06\x12\x17\n\x0fupload_complete\x18\x0b \x01(\x08\x12\x13\n\x0b\x64uration_ms\x18\x0c \x01(\r\"z\n&CGameRecording_CreateShareClip_Request\x12!\n\x04\x63lip\x18\x02 \x01(\x0b\x32\x13.CGameRecordingClip\x12-\n\tvideo_def\x18\x03 \x03(\x0b\x32\x1a.CMsgVideoGameRecordingDef\"L\n\'CGameRecording_CreateShareClip_Response\x12!\n\x04\x63lip\x18\x01 \x01(\x0b\x32\x13.CGameRecordingClip\":\n\'CGameRecording_DeleteSharedClip_Request\x12\x0f\n\x07\x63lip_id\x18\x02 \x01(\x06\"*\n(CGameRecording_DeleteSharedClip_Response\"=\n*CGameRecording_GetSingleSharedClip_Request\x12\x0f\n\x07\x63lip_id\x18\x02 \x01(\x06\"P\n+CGameRecording_GetSingleSharedClip_Response\x12!\n\x04\x63lip\x18\x01 \x01(\x0b\x32\x13.CGameRecordingClip\"\xb9\x01\n/CVideo_BeginGameRecordingSegmentsUpload_Request\x12\x14\n\x0crecording_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x63omponent_name\x18\x02 \x01(\t\x12\x1b\n\x13representation_name\x18\x03 \x01(\t\x12;\n\x11segments_to_store\x18\x04 \x03(\x0b\x32 .CVideo_GameRecordingSegmentInfo\"\x87\x01\n0CVideo_BeginGameRecordingSegmentsUpload_Response\x12?\n\x0fsegments_needed\x18\x01 \x03(\x0b\x32&.CVideo_GameRecordingSegmentUploadInfo\x12\x12\n\ncall_again\x18\x02 \x01(\x08\"\xc8\x01\n0CVideo_CommitGameRecordingSegmentsUpload_Request\x12\x14\n\x0crecording_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x63omponent_name\x18\x02 \x01(\t\x12\x1b\n\x13representation_name\x18\x03 \x01(\t\x12\x1c\n\x14\x66irst_segment_number\x18\x04 \x01(\r\x12\x14\n\x0cnum_segments\x18\x05 \x01(\r\x12\x15\n\rupload_result\x18\x06 \x01(\r\"3\n1CVideo_CommitGameRecordingSegmentsUpload_Response\"R\n:CVideo_GameRecordingGetNextBatchOfSegmentsToUpload_Request\x12\x14\n\x0crecording_id\x18\x01 \x01(\x04\"~\n;CVideo_GameRecordingGetNextBatchOfSegmentsToUpload_Response\x12?\n\x0fsegments_needed\x18\x01 \x03(\x0b\x32&.CVideo_GameRecordingSegmentUploadInfo\"\x85\x01\n0CVideo_GameRecordingCommitSegmentUploads_Request\x12\x14\n\x0crecording_id\x18\x01 \x01(\x04\x12;\n\x11segments_uploaded\x18\x02 \x03(\x0b\x32 .CVideo_GameRecordingSegmentInfo\"3\n1CVideo_GameRecordingCommitSegmentUploads_Response2\xd4\x02\n\x11GameRecordingClip\x12\x64\n\x0f\x43reateShareClip\x12\'.CGameRecording_CreateShareClip_Request\x1a(.CGameRecording_CreateShareClip_Response\x12g\n\x10\x44\x65leteSharedClip\x12(.CGameRecording_DeleteSharedClip_Request\x1a).CGameRecording_DeleteSharedClip_Response\x12p\n\x13GetSingleSharedClip\x12+.CGameRecording_GetSingleSharedClip_Request\x1a,.CGameRecording_GetSingleSharedClip_Response2\xbf\x04\n\tVideoClip\x12\x87\x01\n BeginGameRecordingSegmentsUpload\x12\x30.CVideo_BeginGameRecordingSegmentsUpload_Request\x1a\x31.CVideo_BeginGameRecordingSegmentsUpload_Response\x12\x8a\x01\n!CommitGameRecordingSegmentsUpload\x12\x31.CVideo_CommitGameRecordingSegmentsUpload_Request\x1a\x32.CVideo_CommitGameRecordingSegmentsUpload_Response\x12\x9b\x01\n\x1eGetNextBatchOfSegmentsToUpload\x12;.CVideo_GameRecordingGetNextBatchOfSegmentsToUpload_Request\x1a<.CVideo_GameRecordingGetNextBatchOfSegmentsToUpload_Response\x12}\n\x14\x43ommitSegmentUploads\x12\x31.CVideo_GameRecordingCommitSegmentUploads_Request\x1a\x32.CVideo_GameRecordingCommitSegmentUploads_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_gamerecording_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CVIDEOMANAGERCLIPID._serialized_start=138
  _CVIDEOMANAGERCLIPID._serialized_end=318
  _CGAMERECORDINGCLIP._serialized_start=321
  _CGAMERECORDINGCLIP._serialized_end=538
  _CGAMERECORDING_CREATESHARECLIP_REQUEST._serialized_start=540
  _CGAMERECORDING_CREATESHARECLIP_REQUEST._serialized_end=662
  _CGAMERECORDING_CREATESHARECLIP_RESPONSE._serialized_start=664
  _CGAMERECORDING_CREATESHARECLIP_RESPONSE._serialized_end=740
  _CGAMERECORDING_DELETESHAREDCLIP_REQUEST._serialized_start=742
  _CGAMERECORDING_DELETESHAREDCLIP_REQUEST._serialized_end=800
  _CGAMERECORDING_DELETESHAREDCLIP_RESPONSE._serialized_start=802
  _CGAMERECORDING_DELETESHAREDCLIP_RESPONSE._serialized_end=844
  _CGAMERECORDING_GETSINGLESHAREDCLIP_REQUEST._serialized_start=846
  _CGAMERECORDING_GETSINGLESHAREDCLIP_REQUEST._serialized_end=907
  _CGAMERECORDING_GETSINGLESHAREDCLIP_RESPONSE._serialized_start=909
  _CGAMERECORDING_GETSINGLESHAREDCLIP_RESPONSE._serialized_end=989
  _CVIDEO_BEGINGAMERECORDINGSEGMENTSUPLOAD_REQUEST._serialized_start=992
  _CVIDEO_BEGINGAMERECORDINGSEGMENTSUPLOAD_REQUEST._serialized_end=1177
  _CVIDEO_BEGINGAMERECORDINGSEGMENTSUPLOAD_RESPONSE._serialized_start=1180
  _CVIDEO_BEGINGAMERECORDINGSEGMENTSUPLOAD_RESPONSE._serialized_end=1315
  _CVIDEO_COMMITGAMERECORDINGSEGMENTSUPLOAD_REQUEST._serialized_start=1318
  _CVIDEO_COMMITGAMERECORDINGSEGMENTSUPLOAD_REQUEST._serialized_end=1518
  _CVIDEO_COMMITGAMERECORDINGSEGMENTSUPLOAD_RESPONSE._serialized_start=1520
  _CVIDEO_COMMITGAMERECORDINGSEGMENTSUPLOAD_RESPONSE._serialized_end=1571
  _CVIDEO_GAMERECORDINGGETNEXTBATCHOFSEGMENTSTOUPLOAD_REQUEST._serialized_start=1573
  _CVIDEO_GAMERECORDINGGETNEXTBATCHOFSEGMENTSTOUPLOAD_REQUEST._serialized_end=1655
  _CVIDEO_GAMERECORDINGGETNEXTBATCHOFSEGMENTSTOUPLOAD_RESPONSE._serialized_start=1657
  _CVIDEO_GAMERECORDINGGETNEXTBATCHOFSEGMENTSTOUPLOAD_RESPONSE._serialized_end=1783
  _CVIDEO_GAMERECORDINGCOMMITSEGMENTUPLOADS_REQUEST._serialized_start=1786
  _CVIDEO_GAMERECORDINGCOMMITSEGMENTUPLOADS_REQUEST._serialized_end=1919
  _CVIDEO_GAMERECORDINGCOMMITSEGMENTUPLOADS_RESPONSE._serialized_start=1921
  _CVIDEO_GAMERECORDINGCOMMITSEGMENTUPLOADS_RESPONSE._serialized_end=1972
  _GAMERECORDINGCLIP._serialized_start=1975
  _GAMERECORDINGCLIP._serialized_end=2315
  _VIDEOCLIP._serialized_start=2318
  _VIDEOCLIP._serialized_end=2893
_builder.BuildServices(DESCRIPTOR, 'steammessages_gamerecording_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_lobbymatchmaking.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$steammessages_lobbymatchmaking.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x9e\x01\n-LobbyMatchmakingLegacy_GetLobbyStatus_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rsteamid_lobby\x18\x02 \x01(\x06\x12\x17\n\x0f\x63laim_ownership\x18\x03 \x01(\x08\x12\x18\n\x10\x63laim_membership\x18\x04 \x01(\x08\x12\x13\n\x0bversion_num\x18\x05 \x01(\r\"\x93\x01\n.LobbyMatchmakingLegacy_GetLobbyStatus_Response\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rsteamid_lobby\x18\x02 \x01(\x06\x12:\n\x0clobby_status\x18\x03 \x01(\x0e\x32\r.ELobbyStatus:\x15k_ELobbyStatusInvalid*\x81\x01\n\x0c\x45LobbyStatus\x12\x19\n\x15k_ELobbyStatusInvalid\x10\x00\x12\x18\n\x14k_ELobbyStatusExists\x10\x01\x12\x1e\n\x1ak_ELobbyStatusDoesNotExist\x10\x02\x12\x1c\n\x18k_ELobbyStatusNotAMember\x10\x03\x32\x8b\x01\n\x16LobbyMatchmakingLegacy\x12q\n\x0eGetLobbyStatus\x12..LobbyMatchmakingLegacy_GetLobbyStatus_Request\x1a/.LobbyMatchmakingLegacy_GetLobbyStatus_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_lobbymatchmaking_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _ELOBBYSTATUS._serialized_start=412
  _ELOBBYSTATUS._serialized_end=541
  _LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_REQUEST._serialized_start=101
  _LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_REQUEST._serialized_end=259
  _LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_RESPONSE._serialized_start=262
  _LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_RESPONSE._serialized_end=409
  _LOBBYMATCHMAKINGLEGACY._serialized_start=544
  _LOBBYMATCHMAKINGLEGACY._serialized_end=683
_builder.BuildServices(DESCRIPTOR, 'steammessages_lobbymatchmaking_pb2', globals())
# @@protoc_insertion_point(module_scope)
